(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    266863,       7325]
NotebookOptionsPosition[    252572,       7085]
NotebookOutlinePosition[    252981,       7101]
CellTagsIndexPosition[    252938,       7098]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Brodsky - Lepage Constraints", "Title",
 CellChangeTimes->{{3.809761330136137*^9, 
  3.80976134649261*^9}},ExpressionUUID->"71d6ba4a-c817-4eff-af2f-\
87e0d0bd0fa8"],

Cell["\<\
We check some of the calculations from Martin' s and Peter' s paper on the \
asymptotic behavior of mesons transition form factors.
See also https://arxiv.org/pdf/2004.06127.pdf.\
\>", "Text",
 CellChangeTimes->{{3.809761357983405*^9, 3.809761407308383*^9}, {
  3.809761562947461*^9, 
  3.8097615777216997`*^9}},ExpressionUUID->"8ee7c4eb-e3f7-47b1-8806-\
b5a09d2617d2"],

Cell[CellGroupData[{

Cell["Pion Distribution Function and Form Factor at High Energies", "Section",
 CellChangeTimes->{{3.809759978055902*^9, 3.809759988191931*^9}, {
  3.8097635105726748`*^9, 
  3.8097635256542473`*^9}},ExpressionUUID->"f5fb4b36-0a04-4d2f-a83e-\
aeb9aaedd440"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"In", " ", "the", " ", "following"}], ",", " ", 
    RowBox[{
     RowBox[{
     "we", " ", "examine", " ", "some", " ", "equations", " ", "from", " ", 
      RowBox[{"https", ":"}]}], "//", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"arxiv", ".", "org"}], "/", "pdf"}], "/", 
       RowBox[{"2004.06127", ".", "pdf"}]}], " ", "in", " ", "more", " ", 
      RowBox[{"detail", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]\[Pi]", "[", "u_", "]"}], ":=", 
     RowBox[{"6", "u", 
      RowBox[{"(", 
       RowBox[{"1", "-", "u"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F\[Pi]\[Gamma]\[Gamma]", "[", 
      RowBox[{"q1Sq_", ",", "q2Sq_"}], "]"}], ":=", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", "2"}], "F\[Pi]"}], "3"], 
      RowBox[{"Integrate", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"\[Phi]\[Pi]", "[", "u", "]"}], 
         RowBox[{
          RowBox[{"u", "*", "q1Sq"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], "*", "q2Sq"}]}]], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "0", ",", "1"}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"F\[Pi]\[Gamma]\[Gamma]", "[", 
    RowBox[{"qSq", ",", "qSq"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"F\[Pi]\[Gamma]\[Gamma]", "[", 
    RowBox[{"qSq", ",", "0"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.809245318431369*^9, 3.809245410282896*^9}, {
  3.8092454426331244`*^9, 3.80924549185205*^9}, {3.809245728974578*^9, 
  3.809245747095581*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"9dc681e4-2297-49fc-84c8-ebfc4cb422b0"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "F\[Pi]"}], 
    RowBox[{"3", " ", "qSq"}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.809245749801903*^9, 3.809775822267828*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"dd745792-2fd3-4776-97de-884ba5355449"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "F\[Pi]"}], "qSq"]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.809245749801903*^9, 3.809775822271915*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"02c464e8-b819-4d42-b320-2fdfd22f360e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lorentz Structures and Helicity Amplitudes", "Chapter",
 CellChangeTimes->{{3.8097651930048*^9, 
  3.809765210678267*^9}},ExpressionUUID->"5b7cd0ac-7c94-410b-9ae6-\
6f00f12ab45c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellChangeTimes->{{3.8097600174510736`*^9, 3.809760028673172*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"420a0d6f-e81f-4b30-aba9-919cc4401a3d"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"FeynCalc \"\>", "Text",
     StripOnInput->False,
     FontWeight->Bold], "\[InvisibleSpace]", 
    StyleBox["\<\"9.2.0. For help, use the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"documentation", " ", "center"}],
       BaseStyle->"Link",
       ButtonData:>"paclet:FeynCalc/",
       ButtonNote->"paclet:FeynCalc/"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\", check out the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["wiki",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" or write to the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"mailing", " ", 
        RowBox[{"list", "."}]}],
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["http://www.feyncalc.org/forum/"], None},
       ButtonNote->"http://www.feyncalc.org/forum/"],
      DisplayForm], "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["FeynCalc ", "Text", Bold], 
    Style["9.2.0. For help, use the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "documentation center", BaseStyle -> "Link", ButtonData :> 
       "paclet:FeynCalc/", ButtonNote -> "paclet:FeynCalc/"]], "Text"], 
    Style[", check out the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["wiki", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" or write to the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["mailing list.", ButtonData :> {
         URL["http://www.feyncalc.org/forum/"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> "http://www.feyncalc.org/forum/"]], "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.809760023657181*^9, 3.809760030309811*^9}, 
   3.8097758246002283`*^9},
 CellLabel->
  "During evaluation of \
In[5]:=",ExpressionUUID->"d9aca1fe-9c08-4648-857f-bc52b18b8419"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"See also the supplied \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"examples", "."}],
       BaseStyle->"Hyperlink",
       ButtonFunction:>SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]],
       Evaluator->Automatic,
       Method->"Preemptive"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" If you use FeynCalc in your research, please cite\"\>", 
     "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["See also the supplied ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "examples.", BaseStyle -> "Hyperlink", ButtonFunction :> SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]], Evaluator -> 
       Automatic, Method -> "Preemptive"]], "Text"], 
    Style[" If you use FeynCalc in your research, please cite", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.809760023657181*^9, 3.809760030309811*^9}, 
   3.809775824605524*^9},
 CellLabel->
  "During evaluation of \
In[5]:=",ExpressionUUID->"9d3176cb-bc6f-4629-827a-e9ffa29a17c1"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, Comput. \
Phys. Commun., 207C, 432-444, 2016, arXiv:1601.01167\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.809760023657181*^9, 3.809760030309811*^9}, 
   3.8097758246076593`*^9},
 CellLabel->
  "During evaluation of \
In[5]:=",ExpressionUUID->"4d45619a-b40e-4db4-aa78-8acf805bfeb3"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] R. Mertig, M. B\[ODoubleDot]hm, and A. Denner, \
Comput. Phys. Commun., 64, 345-359, 1991.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.809760023657181*^9, 3.809760030309811*^9}, 
   3.8097758246094027`*^9},
 CellLabel->
  "During evaluation of \
In[5]:=",ExpressionUUID->"bfecb07f-5c66-4125-8de2-9cc1722a46f3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\[Pi]\[Gamma]\[Gamma] (or, in general, P\[Gamma]\[Gamma]) Coupling and \
Decay Width", "Section",
 CellChangeTimes->{{3.809759998696877*^9, 3.809760009811984*^9}, {
  3.8097612449954033`*^9, 
  3.809761250693516*^9}},ExpressionUUID->"fa45b845-8c52-4d7a-8606-\
fce482ac74c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Invariant", " ", "Amplitude", " ", "squared", " ", "for", " ", "on"}], 
    "-", 
    RowBox[{"shell", " ", 
     RowBox[{"Photons", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q1", ",", "q2"}], "]"}], "=", 
     FractionBox[
      SuperscriptBox["m\[Pi]", "2"], "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q1", ",", "q1"}], "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q2", ",", "q2"}], "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"\[Pi]\[Gamma]\[Gamma]Amp", "=", 
    RowBox[{
     SuperscriptBox["e", "4"], 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"MT", "[", 
          RowBox[{"\[Mu]", ",", "\[Kappa]"}], "]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"MT", "[", 
          RowBox[{"\[Nu]", ",", "\[Delta]"}], "]"}]}], ")"}], 
       RowBox[{"LeviCivita", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
        "]"}], 
       RowBox[{"LeviCivita", "[", 
        RowBox[{"\[Kappa]", ",", "\[Delta]", ",", "\[Rho]", ",", "\[Sigma]"}],
         "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Alpha]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Beta]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Rho]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Sigma]"}], "]"}]}], "]"}], 
     SuperscriptBox["F", "2"]}]}]}]}]], "Input",
 CellChangeTimes->{{3.809760032647922*^9, 3.809760173973654*^9}, {
  3.8097602681910973`*^9, 3.809760277770525*^9}, {3.809760590909594*^9, 
  3.8097606080455723`*^9}, {3.809760685498616*^9, 3.809760820887074*^9}, {
  3.8097611497243423`*^9, 3.809761158458659*^9}, {3.809765364337558*^9, 
  3.8097653694507217`*^9}, {3.8097660279671917`*^9, 3.8097660393300734`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"54ca3f32-a947-4a10-a6fc-1283bce4327b"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["e", "4"], " ", 
   SuperscriptBox["F", "2"], " ", 
   SuperscriptBox["m\[Pi]", "4"]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.809760141732885*^9, 3.8097601742669077`*^9}, 
   3.809760609854177*^9, 3.80976076785702*^9, 3.809760821269706*^9, {
   3.809761150977749*^9, 3.809761158783292*^9}, 3.809765371671565*^9, 
   3.809775826196105*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"db45e79c-8c12-4408-9574-e176dc7a43f1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Kallen", " ", "Function", " ", "and", " ", "Decay", " ", "Width", " ", 
     "for", " ", "on"}], "-", 
    RowBox[{"shell", " ", 
     RowBox[{"Photons", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"], "+", 
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"2", "x", " ", "y"}], " ", "-", 
      RowBox[{"2", "x", " ", "z"}], " ", "-", 
      RowBox[{"2", "y", " ", "z"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"\[CapitalGamma]\[Pi]\[Gamma]\[Gamma]", "=", 
    RowBox[{
     FractionBox["1", "2"], 
     FractionBox[
      FractionBox[
       SuperscriptBox[
        RowBox[{"\[Lambda]", "[", 
         RowBox[{
          SuperscriptBox["m\[Pi]", "2"], ",", "0", ",", "0"}], "]"}], 
        RowBox[{"1", "/", "2"}]], 
       RowBox[{"2", "m\[Pi]"}]], 
      RowBox[{"8", "\[Pi]", " ", 
       SuperscriptBox["m\[Pi]", "2"]}]], "\[Pi]\[Gamma]\[Gamma]Amp"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Insert", " ", "\[Alpha]"}], "=", 
     RowBox[{
      FractionBox[
       SuperscriptBox["e", "2"], 
       RowBox[{"4", "\[Pi]"}]], "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox["\[CapitalGamma]\[Pi]\[Gamma]\[Gamma]", 
      SuperscriptBox["e", "4"]], "*", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "\[Pi]", " ", "\[Alpha]"}], ")"}], "2"]}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.809759784907127*^9, 3.809759909063876*^9}, {
   3.809759955636092*^9, 3.80975996506354*^9}, {3.8097601883870287`*^9, 
   3.809760201831805*^9}, {3.809760617349784*^9, 3.8097606186845713`*^9}, {
   3.809760662494055*^9, 3.809760671418456*^9}, {3.8097611622801857`*^9, 
   3.809761222026039*^9}, {3.809765377191187*^9, 3.809765380303193*^9}, {
   3.809766021801662*^9, 3.809766046278327*^9}, 3.8097736678714933`*^9},
 CellLabel->"In[10]:=",ExpressionUUID->"9ecce627-cd03-468d-9c31-593293b77d4f"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["e", "4"], " ", 
    SuperscriptBox["F", "2"], " ", "m\[Pi]", " ", 
    SqrtBox[
     SuperscriptBox["m\[Pi]", "4"]]}], 
   RowBox[{"64", " ", "\[Pi]"}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.809760205269073*^9, 3.809760619737583*^9, {3.809760663274818*^9, 
   3.809760672032158*^9}, 3.8097611659332933`*^9, {3.809761210997389*^9, 
   3.80976122246439*^9}, 3.809765381860239*^9, 3.809775827267232*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"c9056001-7db6-49c7-b8c2-44bef6e8db1d"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "4"], " ", "\[Pi]", " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   SuperscriptBox["F", "2"], " ", "m\[Pi]", " ", 
   SqrtBox[
    SuperscriptBox["m\[Pi]", "4"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.809760205269073*^9, 3.809760619737583*^9, {3.809760663274818*^9, 
   3.809760672032158*^9}, 3.8097611659332933`*^9, {3.809761210997389*^9, 
   3.80976122246439*^9}, 3.809765381860239*^9, 3.8097758273153763`*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"5ff7764d-b1b4-4fcf-bf65-2c2f126f1e7b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["S\[Gamma]\[Gamma] Coupling and Decay Width", "Section",
 CellChangeTimes->{{3.809759998696877*^9, 3.809760009811984*^9}, {
  3.8097612449954033`*^9, 3.809761250693516*^9}, {3.809765225878098*^9, 
  3.809765231564315*^9}},ExpressionUUID->"0aa6a4a7-35ee-4068-bcbb-\
9bc6f6659ffb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Invariant", " ", "Amplitude", " ", "squared", " ", "for", " ", "off"}], 
    "-", 
    RowBox[{"shell", " ", 
     RowBox[{"Photons", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ClearScalarProducts", ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q1", ",", "q2"}], "]"}], "=", 
     FractionBox[
      RowBox[{
       SuperscriptBox["mS", "2"], "-", 
       SuperscriptBox["q1", "2"], "-", 
       SuperscriptBox["q2", "2"]}], "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T1", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q2"}], "]"}], 
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Mu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Nu]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T2", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q1"}], "]"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q2", ",", "q2"}], "]"}], 
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q2"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Mu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Nu]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q1"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Mu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Nu]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"SP", "[", 
        RowBox[{"q2", ",", "q2"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Mu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Nu]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S\[Gamma]\[Gamma]Amp", "=", 
    RowBox[{
     SuperscriptBox["e", "4"], 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"MT", "[", 
          RowBox[{"\[Mu]", ",", "\[Alpha]"}], "]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"MT", "[", 
          RowBox[{"\[Nu]", ",", "\[Beta]"}], "]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "mS"], 
          RowBox[{"T1", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "F1"}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["mS", "3"]], 
          RowBox[{"T2", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "F2"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "mS"], 
          RowBox[{"T1", "[", 
           RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], 
          RowBox[{"Conjugate", "[", "F1", "]"}]}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["mS", "3"]], 
          RowBox[{"T2", "[", 
           RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], 
          RowBox[{"Conjugate", "[", "F2", "]"}]}]}], ")"}]}], 
      "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.809760032647922*^9, 3.809760173973654*^9}, {
   3.8097602681910973`*^9, 3.809760277770525*^9}, {3.809760590909594*^9, 
   3.8097606080455723`*^9}, {3.809760685498616*^9, 3.809760820887074*^9}, {
   3.8097611497243423`*^9, 3.809761158458659*^9}, {3.8097652495001183`*^9, 
   3.8097653603221827`*^9}, {3.809765396074255*^9, 3.809765398280999*^9}, {
   3.809765669586514*^9, 3.8097658020743*^9}, {3.809765999981246*^9, 
   3.809766000293065*^9}, {3.809766050993949*^9, 3.809766057249714*^9}, {
   3.809766333186264*^9, 3.80976639459512*^9}, {3.809766495410226*^9, 
   3.809766521769713*^9}, {3.809767049353984*^9, 3.809767136895432*^9}, 
   3.809773656683392*^9},
 CellLabel->"In[13]:=",ExpressionUUID->"4401c0a9-9946-495c-8f00-da9d14fe7e21"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["e", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "F2", " ", 
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["q1",
           TraditionalForm], "_"],
         TraditionalForm], "2"], " ", 
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["q2",
           TraditionalForm], "_"],
         TraditionalForm], "2"], " ", 
       TemplateBox[{"F1"},
        "Conjugate"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["mS", "2"], "-", 
         SuperscriptBox["q1", "2"], "-", 
         SuperscriptBox["q2", "2"]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["mS", "4"]}]], "+", 
     FractionBox[
      RowBox[{"3", " ", "F1", " ", 
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["q1",
           TraditionalForm], "_"],
         TraditionalForm], "2"], " ", 
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["q2",
           TraditionalForm], "_"],
         TraditionalForm], "2"], " ", 
       TemplateBox[{"F2"},
        "Conjugate"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["mS", "2"], "-", 
         SuperscriptBox["q1", "2"], "-", 
         SuperscriptBox["q2", "2"]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["mS", "4"]}]], "+", 
     FractionBox[
      RowBox[{"F1", " ", 
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["q1",
           TraditionalForm], "_"],
         TraditionalForm], "2"], " ", 
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["q2",
           TraditionalForm], "_"],
         TraditionalForm], "2"], " ", 
       TemplateBox[{"F1"},
        "Conjugate"]}], 
      SuperscriptBox["mS", "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", "F2", " ", 
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["q1",
           TraditionalForm], "_"],
         TraditionalForm], "4"], " ", 
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["q2",
           TraditionalForm], "_"],
         TraditionalForm], "4"], " ", 
       TemplateBox[{"F2"},
        "Conjugate"]}], 
      SuperscriptBox["mS", "6"]], "+", 
     FractionBox[
      RowBox[{"F2", " ", 
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["q1",
           TraditionalForm], "_"],
         TraditionalForm], "2"], " ", 
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["q2",
           TraditionalForm], "_"],
         TraditionalForm], "2"], " ", 
       TemplateBox[{"F2"},
        "Conjugate"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["mS", "2"], "-", 
          SuperscriptBox["q1", "2"], "-", 
          SuperscriptBox["q2", "2"]}], ")"}], "2"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox["mS", "6"]}]], "+", 
     FractionBox[
      RowBox[{"F1", " ", 
       TemplateBox[{"F1"},
        "Conjugate"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["mS", "2"], "-", 
          SuperscriptBox["q1", "2"], "-", 
          SuperscriptBox["q2", "2"]}], ")"}], "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["mS", "2"]}]]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.809760141732885*^9, 3.8097601742669077`*^9}, 
   3.809760609854177*^9, 3.80976076785702*^9, 3.809760821269706*^9, {
   3.809761150977749*^9, 3.809761158783292*^9}, 3.8097658035527573`*^9, 
   3.809765970181892*^9, 3.809766000839149*^9, 3.809766105818933*^9, {
   3.809766369124196*^9, 3.809766394955056*^9}, 3.809766533763288*^9, 
   3.809767008381009*^9, {3.809767072130866*^9, 3.8097671373070383`*^9}, 
   3.809775829275832*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"5420aeb1-2dae-4fa9-be8a-84c111df3f6b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Decay", " ", "Width", " ", "for", " ", "off"}], "-", 
    RowBox[{"shell", " ", 
     RowBox[{"Photons", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"\[CapitalGamma]S\[Gamma]\[Gamma]", "=", 
    RowBox[{
     RowBox[{
      FractionBox[
       FractionBox[
        SuperscriptBox[
         RowBox[{"\[Lambda]", "[", 
          RowBox[{
           SuperscriptBox["mS", "2"], ",", 
           SuperscriptBox["q1", "2"], ",", 
           SuperscriptBox["q2", "2"]}], "]"}], 
         RowBox[{"1", "/", "2"}]], 
        RowBox[{"2", "mS"}]], 
       RowBox[{"8", "\[Pi]", " ", 
        SuperscriptBox["mS", "2"]}]], "*", "S\[Gamma]\[Gamma]Amp"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"For", " ", "on"}], "-", 
       RowBox[{
       "shell", " ", "Photons", " ", "and", " ", "inserting", " ", 
        "\[Alpha]"}]}], "=", 
      FractionBox[
       SuperscriptBox["e", "2"], 
       RowBox[{"4", "\[Pi]"}]]}], ";", " ", 
     RowBox[{
      RowBox[{"the", " ", "factor", " ", 
       FractionBox["1", "2"], " ", "arises", " ", "from", " ", "the", " ", 
       "indistinguishability", " ", "of", " ", "the", " ", "on"}], "-", 
      RowBox[{"shell", " ", 
       RowBox[{"Photons", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q1", ",", "q1"}], "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q2", ",", "q2"}], "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     FractionBox["\[CapitalGamma]S\[Gamma]\[Gamma]", 
      SuperscriptBox["e", "4"]], "*", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "\[Pi]", " ", "\[Alpha]"}], ")"}], "2"]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q1", "\[Rule]", " ", "0"}], ",", 
      RowBox[{"q2", "\[Rule]", " ", "0"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.809759784907127*^9, 3.809759909063876*^9}, {
   3.809759955636092*^9, 3.80975996506354*^9}, {3.8097601883870287`*^9, 
   3.809760201831805*^9}, {3.809760617349784*^9, 3.8097606186845713`*^9}, {
   3.809760662494055*^9, 3.809760671418456*^9}, {3.8097611622801857`*^9, 
   3.809761222026039*^9}, {3.809766010885714*^9, 3.80976601818655*^9}, {
   3.8097660613113832`*^9, 3.8097661512719707`*^9}, {3.80976637613901*^9, 
   3.80976638444648*^9}, {3.8097668689163733`*^9, 3.809767003590528*^9}, {
   3.809767081448151*^9, 3.809767083053322*^9}, {3.809767154768965*^9, 
   3.8097672225897713`*^9}, 3.809773661981786*^9, {3.809775901301745*^9, 
   3.8097759016058807`*^9}},ExpressionUUID->"a55ddf20-19ea-4902-80c5-\
f9c2dfc293f2"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{"64", " ", "\[Pi]", " ", 
     SuperscriptBox["mS", "9"]}]], 
   SuperscriptBox["e", "4"], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["mS", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["mS", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["q1", "2"], "+", 
        SuperscriptBox["q2", "2"]}], ")"}]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["q1", "2"], "-", 
        SuperscriptBox["q2", "2"]}], ")"}], "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       FormBox[
        OverscriptBox[
         FormBox["q1",
          TraditionalForm], "_"],
        TraditionalForm], "2"], " ", 
      SuperscriptBox[
       FormBox[
        OverscriptBox[
         FormBox["q2",
          TraditionalForm], "_"],
        TraditionalForm], "2"], " ", 
      TemplateBox[{"F2"},
       "Conjugate"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8", " ", "F2", " ", 
         SuperscriptBox[
          FormBox[
           OverscriptBox[
            FormBox["q1",
             TraditionalForm], "_"],
           TraditionalForm], "2"], " ", 
         SuperscriptBox[
          FormBox[
           OverscriptBox[
            FormBox["q2",
             TraditionalForm], "_"],
           TraditionalForm], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["mS", "2"], "-", 
           SuperscriptBox["q1", "2"], "-", 
           SuperscriptBox["q2", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", "F1", " ", 
            SuperscriptBox["mS", "2"]}], "+", 
           RowBox[{"F2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mS", "2"], "-", 
              SuperscriptBox["q1", "2"], "-", 
              SuperscriptBox["q2", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      TemplateBox[{"F1"},
       "Conjugate"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["mS", "2"], " ", 
         SuperscriptBox[
          FormBox[
           OverscriptBox[
            FormBox["q1",
             TraditionalForm], "_"],
           TraditionalForm], "2"], " ", 
         SuperscriptBox[
          FormBox[
           OverscriptBox[
            FormBox["q2",
             TraditionalForm], "_"],
           TraditionalForm], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "F1", " ", 
            SuperscriptBox["mS", "2"]}], "+", 
           RowBox[{"3", " ", "F2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["mS", "2"], "-", 
              SuperscriptBox["q1", "2"], "-", 
              SuperscriptBox["q2", "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"F1", " ", 
         SuperscriptBox["mS", "4"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["mS", "2"]}], "+", 
            SuperscriptBox["q1", "2"], "+", 
            SuperscriptBox["q2", "2"]}], ")"}], "2"]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.809760205269073*^9, 3.809760619737583*^9, {3.809760663274818*^9, 
   3.809760672032158*^9}, 3.8097611659332933`*^9, {3.809761210997389*^9, 
   3.80976122246439*^9}, {3.809766106969304*^9, 3.809766151511635*^9}, {
   3.8097663704622917`*^9, 3.809766395921753*^9}, 3.809766536107839*^9, 
   3.8097666597105827`*^9, {3.809766884405098*^9, 3.809766910889962*^9}, {
   3.809766944867041*^9, 3.809766970920137*^9}, 3.809767012283483*^9, {
   3.809767074593727*^9, 3.809767112681579*^9}, {3.80976714644363*^9, 
   3.809767180747183*^9}, 3.809767229387849*^9, 3.8097758306583157`*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"49008e43-f7a1-4c0c-af4b-68b68868d94c"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[Pi]", " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", "F1", " ", 
    SqrtBox[
     SuperscriptBox["mS", "4"]], " ", 
    TemplateBox[{"F1"},
     "Conjugate"]}], 
   RowBox[{"4", " ", "mS"}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.809760205269073*^9, 3.809760619737583*^9, {3.809760663274818*^9, 
   3.809760672032158*^9}, 3.8097611659332933`*^9, {3.809761210997389*^9, 
   3.80976122246439*^9}, {3.809766106969304*^9, 3.809766151511635*^9}, {
   3.8097663704622917`*^9, 3.809766395921753*^9}, 3.809766536107839*^9, 
   3.8097666597105827`*^9, {3.809766884405098*^9, 3.809766910889962*^9}, {
   3.809766944867041*^9, 3.809766970920137*^9}, 3.809767012283483*^9, {
   3.809767074593727*^9, 3.809767112681579*^9}, {3.80976714644363*^9, 
   3.809767180747183*^9}, 3.809767229387849*^9, 3.809775830702526*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"9fb897fe-c8d8-43cf-973c-0a5066017a6a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A\[Gamma]\[Gamma] Coupling and Decay Width", "Section",
 CellChangeTimes->{{3.809759998696877*^9, 3.809760009811984*^9}, {
  3.8097612449954033`*^9, 3.809761250693516*^9}, {3.809765225878098*^9, 
  3.809765231564315*^9}, {3.809767246646278*^9, 
  3.8097672468314466`*^9}},ExpressionUUID->"3788d55f-d502-4d0e-9bdd-\
b16ce117b6bd"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Done", " ", "in", " ", "thesis"}], "..."}], " ", "*)"}]], "Input",\

 CellChangeTimes->{{3.80976724821065*^9, 
  3.809767252145563*^9}},ExpressionUUID->"fd20cadb-d92b-4bbf-9fa1-\
7334c3c21ba5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["T\[Gamma]\[Gamma] Coupling and Decay Width", "Section",
 CellChangeTimes->{{3.809759998696877*^9, 3.809760009811984*^9}, {
  3.8097612449954033`*^9, 3.809761250693516*^9}, {3.809765225878098*^9, 
  3.809765231564315*^9}, {3.809767246646278*^9, 3.8097672468314466`*^9}, {
  3.8097731562707253`*^9, 
  3.809773156469735*^9}},ExpressionUUID->"4d075ae9-1b13-4c1e-b042-\
97dc202fe2d3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Invariant", " ", "Amplitude", " ", "squared", " ", "for", " ", "off"}], 
    "-", 
    RowBox[{"shell", " ", 
     RowBox[{"Photons", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ClearScalarProducts", ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q1", ",", "q2"}], "]"}], "=", 
     FractionBox[
      SuperscriptBox["mT", "2"], "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"P", ",", "P"}], "]"}], "=", 
     SuperscriptBox["mT", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q1", ",", "q1"}], "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q2", ",", "q2"}], "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P", "=", 
     RowBox[{"q1", "+", "q2"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"MT", "[", 
         RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"FV", "[", 
          RowBox[{"P", ",", "\[Mu]"}], "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"P", ",", "\[Nu]"}], "]"}]}], 
        SuperscriptBox["mT", "2"]]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P11", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q1"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Nu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Mu]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P12", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q2"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Nu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Mu]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P21", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q2", ",", "q1"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Nu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Mu]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P22", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q2", ",", "q2"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Nu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Mu]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T1", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_", ",", "\[Beta]_"}], 
      "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Alpha]"}], "]"}], 
       RowBox[{"P21", "[", 
        RowBox[{"\[Nu]", ",", "\[Beta]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"MT", "[", 
        RowBox[{"\[Nu]", ",", "\[Alpha]"}], "]"}], 
       RowBox[{"P12", "[", 
        RowBox[{"\[Mu]", ",", "\[Beta]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Beta]"}], "]"}], 
       RowBox[{"P21", "[", 
        RowBox[{"\[Nu]", ",", "\[Alpha]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"MT", "[", 
        RowBox[{"\[Nu]", ",", "\[Beta]"}], "]"}], 
       RowBox[{"P12", "[", 
        RowBox[{"\[Mu]", ",", "\[Alpha]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"FV", "[", 
           RowBox[{"q1", ",", "\[Alpha]"}], "]"}], 
          RowBox[{"FV", "[", 
           RowBox[{"q2", ",", "\[Beta]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"FV", "[", 
           RowBox[{"q2", ",", "\[Alpha]"}], "]"}], 
          RowBox[{"FV", "[", 
           RowBox[{"q1", ",", "\[Beta]"}], "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q2"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"MT", "[", 
           RowBox[{"\[Mu]", ",", "\[Alpha]"}], "]"}], 
          RowBox[{"MT", "[", 
           RowBox[{"\[Nu]", ",", "\[Beta]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"MT", "[", 
           RowBox[{"\[Nu]", ",", "\[Alpha]"}], "]"}], 
          RowBox[{"MT", "[", 
           RowBox[{"\[Mu]", ",", "\[Beta]"}], "]"}]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T2", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_", ",", "\[Beta]_"}], 
      "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"FV", "[", 
          RowBox[{"q1", ",", "\[Alpha]"}], "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q1", ",", "\[Beta]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"FV", "[", 
          RowBox[{"q2", ",", "\[Alpha]"}], "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q2", ",", "\[Beta]"}], "]"}]}]}], ")"}], 
      RowBox[{"P12", "[", 
       RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T3", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_", ",", "\[Beta]_"}], 
      "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"P11", "[", 
        RowBox[{"\[Mu]", ",", "\[Alpha]"}], "]"}], 
       RowBox[{"P22", "[", 
        RowBox[{"\[Nu]", ",", "\[Beta]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"P11", "[", 
        RowBox[{"\[Mu]", ",", "\[Beta]"}], "]"}], 
       RowBox[{"P22", "[", 
        RowBox[{"\[Nu]", ",", "\[Alpha]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T4", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_", ",", "\[Beta]_"}], 
      "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"P12", "[", 
        RowBox[{"\[Mu]", ",", "\[Alpha]"}], "]"}], 
       RowBox[{"P22", "[", 
        RowBox[{"\[Nu]", ",", "\[Beta]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"P12", "[", 
        RowBox[{"\[Mu]", ",", "\[Beta]"}], "]"}], 
       RowBox[{"P22", "[", 
        RowBox[{"\[Nu]", ",", "\[Alpha]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T5", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_", ",", "\[Beta]_"}], 
      "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"P21", "[", 
        RowBox[{"\[Nu]", ",", "\[Alpha]"}], "]"}], 
       RowBox[{"P11", "[", 
        RowBox[{"\[Mu]", ",", "\[Beta]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"P21", "[", 
        RowBox[{"\[Nu]", ",", "\[Beta]"}], "]"}], 
       RowBox[{"P11", "[", 
        RowBox[{"\[Mu]", ",", "\[Alpha]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"T\[Gamma]\[Gamma]Amp", "=", 
    RowBox[{
     FractionBox["1", "5"], 
     SuperscriptBox["e", "4"], 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"MT", "[", 
          RowBox[{"\[Mu]", ",", "\[Kappa]"}], "]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"MT", "[", 
          RowBox[{"\[Nu]", ",", "\[Delta]"}], "]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "2"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"s", "[", 
              RowBox[{"\[Alpha]", ",", "\[Sigma]"}], "]"}], 
             RowBox[{"s", "[", 
              RowBox[{"\[Rho]", ",", "\[Beta]"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"s", "[", 
              RowBox[{"\[Alpha]", ",", "\[Rho]"}], "]"}], 
             RowBox[{"s", "[", 
              RowBox[{"\[Beta]", ",", "\[Sigma]"}], "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "3"], 
          RowBox[{"s", "[", 
           RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], 
          RowBox[{"s", "[", 
           RowBox[{"\[Rho]", ",", "\[Sigma]"}], "]"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "mT"], 
          RowBox[{"T1", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
           "]"}], "F1"}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["mT", "3"]], 
          RowBox[{"T2", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
           "]"}], "F2"}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["mT", "3"]], 
          RowBox[{"T3", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
           "]"}], "F3"}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["mT", "3"]], 
          RowBox[{"T4", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
           "]"}], "F4"}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["mT", "3"]], 
          RowBox[{"T5", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
           "]"}], "F5"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "mT"], 
          RowBox[{"T1", "[", 
           RowBox[{
           "\[Kappa]", ",", "\[Delta]", ",", "\[Rho]", ",", "\[Sigma]"}], 
           "]"}], 
          RowBox[{"Conjugate", "[", "F1", "]"}]}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["mT", "3"]], 
          RowBox[{"T2", "[", 
           RowBox[{
           "\[Kappa]", ",", "\[Delta]", ",", "\[Rho]", ",", "\[Sigma]"}], 
           "]"}], 
          RowBox[{"Conjugate", "[", "F2", "]"}]}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["mT", "3"]], 
          RowBox[{"T3", "[", 
           RowBox[{
           "\[Kappa]", ",", "\[Delta]", ",", "\[Rho]", ",", "\[Sigma]"}], 
           "]"}], 
          RowBox[{"Conjugate", "[", "F3", "]"}]}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["mT", "3"]], 
          RowBox[{"T4", "[", 
           RowBox[{
           "\[Kappa]", ",", "\[Delta]", ",", "\[Rho]", ",", "\[Sigma]"}], 
           "]"}], 
          RowBox[{"Conjugate", "[", "F4", "]"}]}], "+", 
         RowBox[{
          FractionBox["1", 
           SuperscriptBox["mT", "3"]], 
          RowBox[{"T5", "[", 
           RowBox[{
           "\[Kappa]", ",", "\[Delta]", ",", "\[Rho]", ",", "\[Sigma]"}], 
           "]"}], 
          RowBox[{"Conjugate", "[", "F5", "]"}]}]}], ")"}]}], 
      "]"}]}]}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQfXy3SEpX0htHHY39pSC6QratEUSrrNjRBKJTpe+u
BNEhpYxrQPSqL+u3guiXSXOOgegLutvfg+iwtec+gOgfDAYfeoB0kD/XPxDt
k9DE1AukP/09AaZ3HtmkAqJXJTiZgui4tP++IPpUAqcfiM47Fx8Colf8VQ8F
0Q++Li0H0ZbcwfUgepLC224QXbvQoh9EXwvWvgiiE5fL3AHRUWe3nJ8ApFef
eXsNRPt0bL8Nou/f5+WaCKT/5M3hA9GHRDaCaccGhh4QfSz68WYQ7XGkbheI
tgtYtwdEB/Qbik4C0rrsK8RB9CHRAg0QbZX5SRNE8+zrMgTRbaGTwTTX3GUW
IFqs1MgSRP/7G+cEos3E/oJpAC7dvSM=
  "],
 CellLabel->"In[90]:=",ExpressionUUID->"922f3ee2-a9ab-43d9-b6c2-e3086c99f2b2"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "5"], " ", 
   SuperscriptBox["e", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "F1", " ", 
      SuperscriptBox["mT", "2"], " ", 
      TemplateBox[{"F1"},
       "Conjugate"]}], "+", 
     RowBox[{
      FractionBox["1", "12"], " ", "F2", " ", 
      SuperscriptBox["mT", "2"], " ", 
      TemplateBox[{"F2"},
       "Conjugate"]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.809760141732885*^9, 3.8097601742669077`*^9}, 
   3.809760609854177*^9, 3.80976076785702*^9, 3.809760821269706*^9, {
   3.809761150977749*^9, 3.809761158783292*^9}, 3.8097658035527573`*^9, 
   3.809765970181892*^9, 3.809766000839149*^9, 3.809766105818933*^9, {
   3.809766369124196*^9, 3.809766394955056*^9}, 3.809766533763288*^9, 
   3.809767008381009*^9, {3.809767072130866*^9, 3.8097671373070383`*^9}, 
   3.8097753155344057`*^9, 3.8097758780161867`*^9, 3.8097759925531073`*^9, {
   3.809776061296324*^9, 3.8097760895889893`*^9}, 3.8097761684368553`*^9},
 CellLabel->
  "Out[106]=",ExpressionUUID->"80cba7f2-f7ed-40af-8c0e-d9d426e7d009"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Decay", " ", "Width", " ", "for", " ", "on"}], "-", 
    RowBox[{"shell", " ", 
     RowBox[{"Photons", ".", " ", "The"}], " ", "factor", " ", 
     FractionBox["1", "2"], " ", "arises", " ", "from", " ", "the", " ", 
     "indistinguishability", " ", "of", " ", "the", " ", "on"}], "-", 
    RowBox[{"shell", " ", 
     RowBox[{"Photons", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"\[CapitalGamma]T\[Gamma]\[Gamma]", "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      FractionBox[
       FractionBox[
        SuperscriptBox[
         RowBox[{"\[Lambda]", "[", 
          RowBox[{
           SuperscriptBox["mT", "2"], ",", 
           SuperscriptBox["q1", "2"], ",", 
           SuperscriptBox["q2", "2"]}], "]"}], 
         RowBox[{"1", "/", "2"}]], 
        RowBox[{"2", "mT"}]], 
       RowBox[{"8", "\[Pi]", " ", 
        SuperscriptBox["mT", "2"]}]], "*", "T\[Gamma]\[Gamma]Amp"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Inserting", " ", "\[Alpha]"}], "=", 
     RowBox[{
      FractionBox[
       SuperscriptBox["e", "2"], 
       RowBox[{"4", "\[Pi]"}]], "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    FractionBox["\[CapitalGamma]T\[Gamma]\[Gamma]", 
     SuperscriptBox["e", "4"]], "*", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"4", "\[Pi]", " ", "\[Alpha]"}], ")"}], "2"]}]}]}]], "Input",
 CellChangeTimes->{{3.809759784907127*^9, 3.809759909063876*^9}, {
  3.809759955636092*^9, 3.80975996506354*^9}, {3.8097601883870287`*^9, 
  3.809760201831805*^9}, {3.809760617349784*^9, 3.8097606186845713`*^9}, {
  3.809760662494055*^9, 3.809760671418456*^9}, {3.8097611622801857`*^9, 
  3.809761222026039*^9}, {3.809766010885714*^9, 3.80976601818655*^9}, {
  3.8097660613113832`*^9, 3.8097661512719707`*^9}, {3.80976637613901*^9, 
  3.80976638444648*^9}, {3.8097668689163733`*^9, 3.809767003590528*^9}, {
  3.809767081448151*^9, 3.809767083053322*^9}, {3.809767154768965*^9, 
  3.8097672225897713`*^9}, {3.8097754489931717`*^9, 3.809775462874625*^9}, {
  3.809775924203023*^9, 3.809775924500087*^9}, {3.809776005753731*^9, 
  3.8097760444601107`*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"c70fdad8-0206-4368-b37e-5a3adcf00a35"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["e", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"24", " ", "F1", " ", 
       TemplateBox[{"F1"},
        "Conjugate"]}], "+", 
      RowBox[{"F2", " ", 
       TemplateBox[{"F2"},
        "Conjugate"]}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["mT", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["mT", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"]}], ")"}]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["q1", "2"], "-", 
         SuperscriptBox["q2", "2"]}], ")"}], "2"]}]]}], 
   RowBox[{"1920", " ", "\[Pi]", " ", "mT"}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.809760205269073*^9, 3.809760619737583*^9, {3.809760663274818*^9, 
   3.809760672032158*^9}, 3.8097611659332933`*^9, {3.809761210997389*^9, 
   3.80976122246439*^9}, {3.809766106969304*^9, 3.809766151511635*^9}, {
   3.8097663704622917`*^9, 3.809766395921753*^9}, 3.809766536107839*^9, 
   3.8097666597105827`*^9, {3.809766884405098*^9, 3.809766910889962*^9}, {
   3.809766944867041*^9, 3.809766970920137*^9}, 3.809767012283483*^9, {
   3.809767074593727*^9, 3.809767112681579*^9}, {3.80976714644363*^9, 
   3.809767180747183*^9}, 3.809767229387849*^9, 3.809775887289464*^9, 
   3.809776091815727*^9, 3.809776178790557*^9},
 CellLabel->
  "Out[107]=",ExpressionUUID->"6b11fede-349c-4e2d-a058-c78c9618251f"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[Pi]", " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"24", " ", "F1", " ", 
       TemplateBox[{"F1"},
        "Conjugate"]}], "+", 
      RowBox[{"F2", " ", 
       TemplateBox[{"F2"},
        "Conjugate"]}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["mT", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["mT", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["q1", "2"], "+", 
         SuperscriptBox["q2", "2"]}], ")"}]}], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["q1", "2"], "-", 
         SuperscriptBox["q2", "2"]}], ")"}], "2"]}]]}], 
   RowBox[{"120", " ", "mT"}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.809760205269073*^9, 3.809760619737583*^9, {3.809760663274818*^9, 
   3.809760672032158*^9}, 3.8097611659332933`*^9, {3.809761210997389*^9, 
   3.80976122246439*^9}, {3.809766106969304*^9, 3.809766151511635*^9}, {
   3.8097663704622917`*^9, 3.809766395921753*^9}, 3.809766536107839*^9, 
   3.8097666597105827`*^9, {3.809766884405098*^9, 3.809766910889962*^9}, {
   3.809766944867041*^9, 3.809766970920137*^9}, 3.809767012283483*^9, {
   3.809767074593727*^9, 3.809767112681579*^9}, {3.80976714644363*^9, 
   3.809767180747183*^9}, 3.809767229387849*^9, 3.809775887289464*^9, 
   3.809776091815727*^9, 3.809776178793535*^9},
 CellLabel->
  "Out[108]=",ExpressionUUID->"b8c54b8a-d859-4f57-a823-8d67c599fe95"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Brodsky-Lepage Limit for the Transition Form Factors", "Chapter",
 CellChangeTimes->{{3.8097651930048*^9, 3.809765210678267*^9}, {
  3.809856531715349*^9, 
  3.809856541782036*^9}},ExpressionUUID->"a94ef0ac-6d7e-4a26-bd31-\
eb2e49f91def"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Define", " ", "useful", " ", 
    RowBox[{"functions", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"MyCommutator", "[", 
      RowBox[{"A_", ",", "B_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"A", ".", "B"}], "-", 
      RowBox[{"B", ".", "A"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"MyAntiCommutator", "[", 
      RowBox[{"A_", ",", "B_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"A", ".", "B"}], "+", 
      RowBox[{"B", ".", "A"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8103597942297907`*^9, 3.810359836344823*^9}, {
  3.810467601684957*^9, 3.810467602968851*^9}},
 CellLabel->
  "In[498]:=",ExpressionUUID->"10164ac5-8161-4676-b9d0-41d3983c3518"],

Cell[CellGroupData[{

Cell["Pseudoscalar Mesons", "Section",
 CellChangeTimes->{{3.809856546974785*^9, 
  3.809856554913802*^9}},ExpressionUUID->"9aee6d91-0830-4e98-8d07-\
0d22b3cb6ba0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Gell", "-", 
     RowBox[{"Mann", " ", "Matrices"}]}], ",", " ", 
    RowBox[{"Charge", " ", "Matrix"}], ",", " ", 
    RowBox[{"and", " ", "Mass", " ", 
     RowBox[{"matrix", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Q", "=", 
     RowBox[{"(", GridBox[{
        {
         FractionBox["2", "3"], "0", "0"},
        {"0", 
         RowBox[{"-", 
          FractionBox["1", "3"]}], "0"},
        {"0", "0", 
         RowBox[{"-", 
          FractionBox["1", "3"]}]}
       }], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M", "=", 
     RowBox[{"(", GridBox[{
        {"mu", "0", "0"},
        {"0", "md", "0"},
        {"0", "0", "ms"}
       }], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Lambda]", "=", 
     RowBox[{"List", "[", 
      RowBox[{
       RowBox[{
        SqrtBox[
         FractionBox["2", "3"]], 
        RowBox[{"(", GridBox[{
           {"1", "0", "0"},
           {"0", "1", "0"},
           {"0", "0", "1"}
          }], ")"}]}], ",", 
       RowBox[{"(", GridBox[{
          {"0", "1", "0"},
          {"1", "0", "0"},
          {"0", "0", "0"}
         }], ")"}], ",", 
       RowBox[{"(", GridBox[{
          {"0", 
           RowBox[{"-", "\[ImaginaryI]"}], "0"},
          {"\[ImaginaryI]", "0", "0"},
          {"0", "0", "0"}
         }], ")"}], ",", 
       RowBox[{"(", GridBox[{
          {"1", "0", "0"},
          {"0", 
           RowBox[{"-", "1"}], "0"},
          {"0", "0", "0"}
         }], ")"}], ",", 
       RowBox[{"(", GridBox[{
          {"0", "0", "1"},
          {"0", "0", "0"},
          {"1", "0", "0"}
         }], ")"}], ",", 
       RowBox[{"(", GridBox[{
          {"0", "0", 
           RowBox[{"-", "\[ImaginaryI]"}]},
          {"0", "0", "0"},
          {"\[ImaginaryI]", "0", "0"}
         }], ")"}], ",", 
       RowBox[{"(", GridBox[{
          {"0", "0", "0"},
          {"0", "0", "1"},
          {"0", "1", "0"}
         }], ")"}], ",", 
       RowBox[{"(", GridBox[{
          {"0", "0", "0"},
          {"0", "0", 
           RowBox[{"-", "\[ImaginaryI]"}]},
          {"0", "\[ImaginaryI]", "0"}
         }], ")"}], ",", 
       RowBox[{
        FractionBox["1", 
         SqrtBox["3"]], 
        RowBox[{"(", GridBox[{
           {"1", "0", "0"},
           {"0", "1", "0"},
           {"0", "0", 
            RowBox[{"-", "2"}]}
          }], ")"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"The", " ", "defined", " ", "coefficient", " ", 
       SubscriptBox["C", "a"]}], "=."}], ".."}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"Tr", "[", 
        RowBox[{"Q", ".", "Q", ".", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "//", "Simplify"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"The", " ", "normalization", " ", "of", " ", 
      RowBox[{"Tr", "[", 
       RowBox[{
        SubscriptBox["\[Lambda]", "a"], 
        SubscriptBox["\[Lambda]", "b"]}], "]"}]}], "=", 
     RowBox[{"N", " ", 
      RowBox[{
       SubscriptBox["\[Delta]", "ab"], "."}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Tr", "[", 
    RowBox[{
     RowBox[{"\[Lambda]", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ".", 
     RowBox[{"\[Lambda]", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Trace", " ", "of", " ", "Charge", " ", "matrix", " ", 
     RowBox[{"squared", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Tr", "[", 
    RowBox[{"Q", ".", "Q"}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"The", " ", "divergence", " ", "of", " ", "the", " ", "axial"}], 
     "-", 
     RowBox[{
     "vector", " ", "isovector", " ", "current", " ", "on", " ", "one", " ", 
      RowBox[{"example", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"MyAntiCommutator", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Lambda]", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "2"], ",", "M"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.809856156150599*^9, 3.809856220533064*^9}, {
  3.809856261298831*^9, 3.8098563048620033`*^9}, {3.809856349130233*^9, 
  3.809856513734189*^9}, {3.809856557315867*^9, 3.809856563288767*^9}, {
  3.809856821905797*^9, 3.809856887949185*^9}, {3.8098569236234503`*^9, 
  3.8098569261584187`*^9}, {3.809857082227934*^9, 3.8098570834435453`*^9}, {
  3.8098571917743*^9, 3.8098571987723827`*^9}, {3.8098573343817387`*^9, 
  3.809857380827897*^9}, {3.810281367173799*^9, 3.8102813695075083`*^9}, {
  3.810281725457595*^9, 3.810281752313856*^9}, {3.810359782924103*^9, 
  3.810359788111219*^9}, {3.810359849796102*^9, 3.8103600844725313`*^9}, {
  3.810360128976379*^9, 3.810360156091278*^9}, {3.810371121096856*^9, 
  3.8103711218221073`*^9}, {3.8104676054143267`*^9, 3.8104676056741953`*^9}},
 CellLabel->
  "In[500]:=",ExpressionUUID->"539a2ec1-7871-407f-a49f-44a1e6e95370"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     SqrtBox[
      FractionBox["2", "3"]], "3"], ",", "0", ",", "0", ",", 
    FractionBox["1", "6"], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
    FractionBox["1", 
     RowBox[{"6", " ", 
      SqrtBox["3"]}]]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.809856846298483*^9, 3.809856857425789*^9}, 
   3.809856890797278*^9, 3.8098569268800907`*^9, 3.809857083877079*^9, {
   3.8098571923651648`*^9, 3.809857199081945*^9}, {3.8098573354345703`*^9, 
   3.809857381130238*^9}, 3.810281377004026*^9, {3.810281740183835*^9, 
   3.8102817526244507`*^9}, {3.8103599971285133`*^9, 3.81036005446562*^9}, 
   3.810360163181665*^9, {3.811657616432561*^9, 3.811657621734633*^9}},
 CellLabel->
  "Out[503]=",ExpressionUUID->"2e485cb6-e073-460e-b70e-f921c6f7acbe"],

Cell[BoxData[
 FormBox["2", TraditionalForm]], "Output",
 CellChangeTimes->{{3.809856846298483*^9, 3.809856857425789*^9}, 
   3.809856890797278*^9, 3.8098569268800907`*^9, 3.809857083877079*^9, {
   3.8098571923651648`*^9, 3.809857199081945*^9}, {3.8098573354345703`*^9, 
   3.809857381130238*^9}, 3.810281377004026*^9, {3.810281740183835*^9, 
   3.8102817526244507`*^9}, {3.8103599971285133`*^9, 3.81036005446562*^9}, 
   3.810360163181665*^9, {3.811657616432561*^9, 3.811657621739976*^9}},
 CellLabel->
  "Out[504]=",ExpressionUUID->"01c2f65e-b389-4f74-8383-0cc5bfc90e74"],

Cell[BoxData[
 FormBox[
  FractionBox["2", "3"], TraditionalForm]], "Output",
 CellChangeTimes->{{3.809856846298483*^9, 3.809856857425789*^9}, 
   3.809856890797278*^9, 3.8098569268800907`*^9, 3.809857083877079*^9, {
   3.8098571923651648`*^9, 3.809857199081945*^9}, {3.8098573354345703`*^9, 
   3.809857381130238*^9}, 3.810281377004026*^9, {3.810281740183835*^9, 
   3.8102817526244507`*^9}, {3.8103599971285133`*^9, 3.81036005446562*^9}, 
   3.810360163181665*^9, {3.811657616432561*^9, 3.8116576217441063`*^9}},
 CellLabel->
  "Out[505]=",ExpressionUUID->"ce00cc6d-ae59-42cb-bf79-c933321194c3"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{
       FractionBox["md", "2"], "+", 
       FractionBox["mu", "2"]}], "0"},
     {
      RowBox[{
       FractionBox["md", "2"], "+", 
       FractionBox["mu", "2"]}], "0", "0"},
     {"0", "0", "0"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.809856846298483*^9, 3.809856857425789*^9}, 
   3.809856890797278*^9, 3.8098569268800907`*^9, 3.809857083877079*^9, {
   3.8098571923651648`*^9, 3.809857199081945*^9}, {3.8098573354345703`*^9, 
   3.809857381130238*^9}, 3.810281377004026*^9, {3.810281740183835*^9, 
   3.8102817526244507`*^9}, {3.8103599971285133`*^9, 3.81036005446562*^9}, 
   3.810360163181665*^9, {3.811657616432561*^9, 3.811657621748301*^9}},
 CellLabel->
  "Out[506]=",ExpressionUUID->"a05569bf-5a94-477f-a146-e41ec4563573"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Scalar Mesons", "Section",
 CellChangeTimes->{{3.809856546974785*^9, 3.809856554913802*^9}, {
  3.810371041615597*^9, 
  3.8103710423209267`*^9}},ExpressionUUID->"a7cc3757-aa9b-4788-b49e-\
abf935bafd74"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "factor", " ", "between", " ", "the", " ", "different", " ", 
    "decay", " ", "constants", " ", "for", " ", "the", " ", "scalar", " ", 
    RowBox[{"meson", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Tr", "[", 
       RowBox[{"M", ".", 
        RowBox[{"\[Lambda]", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "//", "Simplify"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "9"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "The", " ", "divergence", " ", "of", " ", "the", " ", "vector", " ", 
     "isovector", " ", "current", " ", "on", " ", "one", " ", 
     RowBox[{"example", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"MyCommutator", "[", 
    RowBox[{"M", ",", 
     FractionBox[
      RowBox[{"\[Lambda]", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "2"]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.809856156150599*^9, 3.809856220533064*^9}, {
  3.809856261298831*^9, 3.8098563048620033`*^9}, {3.809856349130233*^9, 
  3.809856513734189*^9}, {3.809856557315867*^9, 3.809856563288767*^9}, {
  3.809856821905797*^9, 3.809856887949185*^9}, {3.8098569236234503`*^9, 
  3.8098569261584187`*^9}, {3.809857082227934*^9, 3.8098570834435453`*^9}, {
  3.8098571917743*^9, 3.8098571987723827`*^9}, {3.8098573343817387`*^9, 
  3.809857380827897*^9}, {3.810281367173799*^9, 3.8102813695075083`*^9}, {
  3.810281725457595*^9, 3.810281752313856*^9}, {3.810359782924103*^9, 
  3.810359788111219*^9}, {3.810359849796102*^9, 3.8103600844725313`*^9}, {
  3.810360128976379*^9, 3.810360156091278*^9}, {3.81037104739606*^9, 
  3.810371056106312*^9}, {3.810371088813311*^9, 3.8103711016986322`*^9}, {
  3.810371141468943*^9, 3.8103711599508953`*^9}, {3.8104676082655287`*^9, 
  3.810467608488934*^9}},ExpressionUUID->"f458425e-9f45-4159-9055-\
6d32929dbd14"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SqrtBox[
      FractionBox["2", "3"]], " ", 
     RowBox[{"(", 
      RowBox[{"md", "+", "ms", "+", "mu"}], ")"}]}], ",", "0", ",", "0", ",", 
    
    RowBox[{"mu", "-", "md"}], ",", "0", ",", "0", ",", "0", ",", "0", ",", 
    FractionBox[
     RowBox[{"md", "-", 
      RowBox[{"2", " ", "ms"}], "+", "mu"}], 
     SqrtBox["3"]]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.809856846298483*^9, 3.809856857425789*^9}, 
   3.809856890797278*^9, 3.8098569268800907`*^9, 3.809857083877079*^9, {
   3.8098571923651648`*^9, 3.809857199081945*^9}, {3.8098573354345703`*^9, 
   3.809857381130238*^9}, 3.810281377004026*^9, {3.810281740183835*^9, 
   3.8102817526244507`*^9}, {3.8103599971285133`*^9, 3.81036005446562*^9}, 
   3.810360163181665*^9, 3.810371359758726*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"2e8dfa26-637b-49b2-afde-fcb2da737e73"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{
       FractionBox["mu", "2"], "-", 
       FractionBox["md", "2"]}], "0"},
     {
      RowBox[{
       FractionBox["md", "2"], "-", 
       FractionBox["mu", "2"]}], "0", "0"},
     {"0", "0", "0"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.809856846298483*^9, 3.809856857425789*^9}, 
   3.809856890797278*^9, 3.8098569268800907`*^9, 3.809857083877079*^9, {
   3.8098571923651648`*^9, 3.809857199081945*^9}, {3.8098573354345703`*^9, 
   3.809857381130238*^9}, 3.810281377004026*^9, {3.810281740183835*^9, 
   3.8102817526244507`*^9}, {3.8103599971285133`*^9, 3.81036005446562*^9}, 
   3.810360163181665*^9, 3.8103713597971077`*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"3d7edef8-005e-4aa1-9f8c-70d9e882b6e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"b8609643-1009-48cd-8d4d-c5747cdd975f"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"FeynCalc \"\>", "Text",
     StripOnInput->False,
     FontWeight->Bold], "\[InvisibleSpace]", 
    StyleBox["\<\"9.2.0. For help, use the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"documentation", " ", "center"}],
       BaseStyle->"Link",
       ButtonData:>"paclet:FeynCalc/",
       ButtonNote->"paclet:FeynCalc/"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\", check out the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["wiki",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" or write to the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"mailing", " ", 
        RowBox[{"list", "."}]}],
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["http://www.feyncalc.org/forum/"], None},
       ButtonNote->"http://www.feyncalc.org/forum/"],
      DisplayForm], "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["FeynCalc ", "Text", Bold], 
    Style["9.2.0. For help, use the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "documentation center", BaseStyle -> "Link", ButtonData :> 
       "paclet:FeynCalc/", ButtonNote -> "paclet:FeynCalc/"]], "Text"], 
    Style[", check out the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["wiki", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" or write to the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["mailing list.", ButtonData :> {
         URL["http://www.feyncalc.org/forum/"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> "http://www.feyncalc.org/forum/"]], "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.810467595744184*^9, 3.810467621983264*^9}, 
   3.810554816019178*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"127078e6-93a8-43b9-b699-603633230251"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"See also the supplied \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"examples", "."}],
       BaseStyle->"Hyperlink",
       ButtonFunction:>SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]],
       Evaluator->Automatic,
       Method->"Preemptive"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" If you use FeynCalc in your research, please cite\"\>", 
     "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["See also the supplied ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "examples.", BaseStyle -> "Hyperlink", ButtonFunction :> SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]], Evaluator -> 
       Automatic, Method -> "Preemptive"]], "Text"], 
    Style[" If you use FeynCalc in your research, please cite", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.810467595744184*^9, 3.810467621983264*^9}, 
   3.810554816033029*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"30aa5a29-2451-494e-ba11-28fa3eaf9d0e"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, Comput. \
Phys. Commun., 207C, 432-444, 2016, arXiv:1601.01167\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.810467595744184*^9, 3.810467621983264*^9}, 
   3.810554816036542*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"a4b1f289-4482-4a29-9b72-301cc13525aa"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] R. Mertig, M. B\[ODoubleDot]hm, and A. Denner, \
Comput. Phys. Commun., 64, 345-359, 1991.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{{3.810467595744184*^9, 3.810467621983264*^9}, 
   3.8105548160403767`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"70e9eeaf-aed7-4bd5-8976-945b15a2858a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Check", " ", "for", " ", "Gauge", " ", "Invariance", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"only", " ", "fulfilled", " ", "for", " ", 
         SuperscriptBox["mS", "2"]}], "=", "0"}], ")"}], ".", " ", "Two"}], 
     " ", "terms", " ", "calculated", " ", "on", " ", "the", " ", "sheet"}], 
    ",", " ", 
    RowBox[{
     SubscriptBox["q", 
      SubscriptBox["1", "\[Mu]"]], 
     SuperscriptBox["M", "\[Mu]\[Nu]"], " ", "and", " ", 
     SubscriptBox["q", 
      SubscriptBox["2", "\[Nu]"]], 
     SuperscriptBox["M", "\[Mu]\[Nu]"]}], ",", " ", 
    RowBox[{
     RowBox[{"that", " ", "are", " ", "still", " ", "to", " ", "be", " ", 
      RowBox[{"integrated", ".", " ", "Note"}], " ", "that", " ", "the", " ", 
      "respective", " ", "first", " ", "integrals", " ", "always", " ", 
      "vanish", " ", "while", " ", "the", " ", "second", " ", "and", " ", 
      "third", " ", "do", " ", "not", " ", "necessarily", " ", "vanish"}], 
     ";", " ", "however"}], ",", " ", 
    RowBox[{
     RowBox[{"they", " ", "do", " ", "vanish", " ", "for", " ", 
      SuperscriptBox["mS", "2"]}], "=", "0"}], ",", " ", 
    RowBox[{"as", " ", 
     RowBox[{"claimed", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FV", "[", 
     RowBox[{"p", ",", "\[Nu]"}], "]"}], 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"3", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "u"}], "-", "1"}], ")"}], "*", "6", "u", 
       RowBox[{"(", 
        RowBox[{"1", "-", "u"}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"FV", "[", 
      RowBox[{"p", ",", "\[Nu]"}], "]"}], 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"3", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "u"}], "-", "1"}], ")"}], "*", "6", "u", 
        RowBox[{"(", 
         RowBox[{"1", "-", "u"}], ")"}], "*", 
        FractionBox[
         RowBox[{
          SuperscriptBox["u", "2"], 
          SuperscriptBox["mS", "2"]}], 
         RowBox[{
          SuperscriptBox["q1", "2"], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], 
           SuperscriptBox["mS", "2"]}], "-", 
          RowBox[{"2", "u", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"u", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mS", "2"], "-", 
             SuperscriptBox["q1", "2"], "-", 
             SuperscriptBox["q2", "2"]}], ")"}]}]}]]}], ",", 
       RowBox[{"{", 
        RowBox[{"u", ",", "0", ",", "1"}], "}"}]}], "]"}], 
     "\[IndentingNewLine]", 
     RowBox[{"FV", "[", 
      RowBox[{"q1", ",", "\[Nu]"}], "]"}], 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"3", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "u"}], "-", "1"}], ")"}], "*", "6", "u", 
        RowBox[{"(", 
         RowBox[{"1", "-", "u"}], ")"}], "*", 
        FractionBox[
         RowBox[{"u", " ", 
          SuperscriptBox["mS", "2"]}], 
         RowBox[{
          SuperscriptBox["q1", "2"], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], 
           SuperscriptBox["mS", "2"]}], "-", 
          RowBox[{"2", "u", " ", 
           SuperscriptBox["q1", "2"]}], "-", 
          RowBox[{"u", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mS", "2"], "-", 
             SuperscriptBox["q1", "2"], "-", 
             SuperscriptBox["q2", "2"]}], ")"}]}]}]]}], ",", 
       RowBox[{"{", 
        RowBox[{"u", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
    "\[IndentingNewLine]", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.810467570773305*^9, 3.810467576382224*^9}, {
  3.810467633611328*^9, 3.810467811864944*^9}, {3.810468080614225*^9, 
  3.810468102345975*^9}, {3.810486857798237*^9, 3.810486867931067*^9}, {
  3.810486983640273*^9, 3.810486989535863*^9}, {3.810487076433477*^9, 
  3.8104871980608664`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"6ea33835-d082-44ad-af7b-093efe6636db"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.810467703506782*^9, 3.8104677199550743`*^9}, {
   3.8104677544023733`*^9, 3.810467812142161*^9}, 3.8104681054621143`*^9, 
   3.8104869985985003`*^9, 3.8105408494011507`*^9, 3.810554816821534*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"4af6e81c-3a7e-4a5f-8cf3-3aefeccad1a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Projecting", " ", "onto", " ", "the", " ", "BTT", " ", 
    RowBox[{"structures", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"T1", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q2"}], "]"}], 
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Mu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Nu]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T2", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q1"}], "]"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q2", ",", "q2"}], "]"}], 
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q2"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Mu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Nu]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q1"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Mu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Nu]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"SP", "[", 
        RowBox[{"q2", ",", "q2"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Mu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Nu]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "u"}], ")"}], 
          RowBox[{"FV", "[", 
           RowBox[{"q1", ",", "\[Mu]"}], "]"}]}], "-", 
         RowBox[{"u", " ", 
          RowBox[{"FV", "[", 
           RowBox[{"q2", ",", "\[Mu]"}], "]"}]}]}], ")"}], 
       RowBox[{"FV", "[", 
        RowBox[{
         RowBox[{"q1", "+", "q2"}], ",", "\[Nu]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "u"}], ")"}], 
          RowBox[{"FV", "[", 
           RowBox[{"q1", ",", "\[Nu]"}], "]"}]}], "-", 
         RowBox[{"u", " ", 
          RowBox[{"FV", "[", 
           RowBox[{"q2", ",", "\[Nu]"}], "]"}]}]}], ")"}], 
       RowBox[{"FV", "[", 
        RowBox[{
         RowBox[{"q1", "+", "q2"}], ",", "\[Mu]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "u"}], ")"}], 
          RowBox[{"SP", "[", 
           RowBox[{
            RowBox[{"q1", "+", "q2"}], ",", "q1"}], "]"}]}], "-", 
         RowBox[{"u", " ", 
          RowBox[{"SP", "[", 
           RowBox[{
            RowBox[{"q1", "+", "q2"}], ",", "q2"}], "]"}]}]}], ")"}]}]}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}]}], "+", 
         RowBox[{"b", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}]}]}], "\[Equal]", 
        
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
          RowBox[{"T1", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}]}], "&&", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}]}], "+", 
         RowBox[{"b", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}]}]}], "\[Equal]", 
        
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
          RowBox[{"T2", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b"}], "}"}]}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.810543802406384*^9, 3.8105438370707407`*^9}, 
   3.8105439161100388`*^9, {3.81054420579918*^9, 3.810544212362111*^9}, {
   3.810544251133698*^9, 3.81054427824727*^9}, {3.8105443987837353`*^9, 
   3.810544769937418*^9}, {3.810544817489812*^9, 3.810544863186887*^9}, {
   3.81054817047011*^9, 3.810548202908085*^9}, {3.810549852636469*^9, 
   3.810549853018675*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"c1c1862f-aacf-4591-8e87-d4c009c064b8"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", 
      RowBox[{
       RowBox[{"2", " ", "u"}], "-", "1"}]}], ",", 
     RowBox[{"b", "\[Rule]", 
      RowBox[{
       FractionBox["u", 
        SuperscriptBox[
         FormBox[
          OverscriptBox[
           FormBox["q1",
            TraditionalForm], "_"],
          TraditionalForm], "2"]], "+", 
       FractionBox[
        RowBox[{"u", "-", "1"}], 
        SuperscriptBox[
         FormBox[
          OverscriptBox[
           FormBox["q2",
            TraditionalForm], "_"],
          TraditionalForm], "2"]]}]}]}], "}"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.8105447114103117`*^9, 3.810544772025465*^9, 
  3.810544827392755*^9, 3.8105448642003736`*^9, 3.810548203601001*^9, 
  3.81054985361659*^9, 3.810554820256195*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"b9a82dc4-fbd5-4f2e-853c-010810ecf4d6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Rewriting", " ", "of", " ", "the", " ", "second", " ", "form", " ", 
    "factor", " ", 
    SubsuperscriptBox["F", "2", "S"], 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["q", "1", "2"], ",", 
      SubsuperscriptBox["q", "2", "2"]}], ")"}], " ", "for", " ", "the", " ", 
    "scalar", " ", "mesons", " ", "by", " ", "using", " ", "integration", " ",
     "by", " ", 
    RowBox[{"parts", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", "u_", "]"}], ":=", 
     RowBox[{"6", "u", 
      RowBox[{"(", 
       RowBox[{"1", "-", "u"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Num", "[", "u_", "]"}], ":=", 
     RowBox[{"3", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "u"}], "-", "1"}], ")"}], 
      RowBox[{"\[Phi]", "[", "u", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Den", "[", "u_", "]"}], ":=", 
     FractionBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", " ", 
         SuperscriptBox["q2", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"u", "-", "1"}], ")"}], 
         SuperscriptBox["q1", "2"]}]}], ")"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"u", " ", 
          SuperscriptBox["q2", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "u"}], ")"}], 
          SuperscriptBox["q1", "2"]}]}], ")"}], 
       SuperscriptBox["q1", "2"], 
       SuperscriptBox["q2", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"Num", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
     RowBox[{"Den", "[", "u", "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{"u", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"Num", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"Den", "[", "u", "]"}], ",", "u"}], "]"}]}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.810549856017008*^9, 3.8105500251570683`*^9}, {
   3.810550084727529*^9, 3.810550108034891*^9}, {3.810550900740589*^9, 
   3.81055090338063*^9}, {3.810550987301873*^9, 3.810551012952799*^9}, 
   3.810561018335664*^9, {3.810561060175823*^9, 3.810561080392806*^9}, {
   3.811171351529481*^9, 3.811171357558799*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"05922445-603e-48ce-a6c5-12da3fd0cc57"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.810549985138585*^9, 3.8105500256669207`*^9}, {
   3.810550097369534*^9, 3.810550108405212*^9}, 3.810550906395042*^9, {
   3.8105509915385513`*^9, 3.8105510143507853`*^9}, 3.81117150048769*^9},
 CellLabel->
  "Out[129]=",ExpressionUUID->"eea75eee-9069-4d5a-b346-9ba799575cc8"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"18", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"u", "-", "1"}], ")"}], "2"], " ", 
     SuperscriptBox["u", "2"]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["q1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "1"}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["q2", "2"], " ", "u"}]}], ")"}], "2"]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.810549985138585*^9, 3.8105500256669207`*^9}, {
   3.810550097369534*^9, 3.810550108405212*^9}, 3.810550906395042*^9, {
   3.8105509915385513`*^9, 3.8105510143507853`*^9}, 3.811171500549203*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"0b866110-914b-4608-92e9-3ef909c8e3c3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Axial-Vector Mesons", "Section",
 CellChangeTimes->{{3.809856546974785*^9, 3.809856554913802*^9}, {
  3.810371041615597*^9, 3.8103710423209267`*^9}, {3.810561013805808*^9, 
  3.810561016233774*^9}},ExpressionUUID->"676e1e12-28e9-4a02-b33e-\
15142f218c57"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Wandzura", "-", 
    RowBox[{
    "Wilczek", " ", "Relations", " ", "for", " ", "the", " ", "higher"}], "-", 
    RowBox[{"twist", " ", 
     SubscriptBox["\[Phi]", "\[Perpendicular]"], 
     RowBox[{"(", "u", ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
        "relating", " ", "it", " ", "to", " ", "the", " ", "leading", " ", 
         "twist"}], "-", 
        RowBox[{"2", " ", "distribution", " ", "amplitudes"}]}], ",", " ", 
       RowBox[{
        RowBox[{"effectively", " ", "neglecting", " ", "three"}], "-", 
        RowBox[{"parton", " ", "contributions"}]}]}], ")"}], " ", "in", " ", 
     "order", " ", "to", " ", "obtain", " ", "a", " ", "gauge"}], "-", 
    RowBox[{"invariant", " ", "result", " ", "for", " ", "the", " ", 
     RowBox[{"TFFs", ".", " ", "The"}], " ", "higher"}], "-", 
    RowBox[{"twist", " ", 
     SubscriptBox["\[Phi]", "3"], 
     RowBox[{"(", "u", ")"}], " ", "does", " ", "not", " ", "actually", " ", 
     "contribute", " ", "due", " ", "to", " ", "the", " ", "antisymmetry", 
     " ", "of", " ", "the", " ", "epsilon", " ", 
     RowBox[{"tensor", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", "u_", "]"}], ":=", 
     RowBox[{"6", "u", 
      RowBox[{"(", 
       RowBox[{"1", "-", "u"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]Perp", "[", "u_", "]"}], ":=", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Integrate", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"\[Phi]", "[", "v", "]"}], 
           RowBox[{"1", "-", "v"}]], ",", 
          RowBox[{"{", 
           RowBox[{"v", ",", "0", ",", "u"}], "}"}]}], "]"}], "+", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"\[Phi]", "[", "v", "]"}], "v"], ",", 
          RowBox[{"{", 
           RowBox[{"v", ",", "u", ",", "1"}], "}"}]}], "]"}]}], ")"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"\[Phi]Perp", "[", "u", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", "1"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.810561083105915*^9, 3.810561168199458*^9}, {
  3.811049727651291*^9, 3.811049865552992*^9}, {3.811049930535976*^9, 
  3.8110499310631533`*^9}},
 CellLabel->
  "In[278]:=",ExpressionUUID->"3d96dd02-8c6f-4f48-ac5f-ac5e0bc12f82"],

Cell[BoxData[
 FormBox[
  GraphicsBox[{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwt2Hk0ld0XB3BzQopIlMosSSWhwrekyRCiSKZXGkjK0BsaUMiUJomiiObB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        "]]},
      Annotation[#, "Charting`Private`Tag$12604#1"]& ]}, {}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0.7500000177707473},
   BaseStyle->{FontFamily -> "Arial"},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{{0, 1}, {0.7500000177707473, 1.4999999387755119`}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}], TraditionalForm]], "Output",
 CellChangeTimes->{3.810561169974587*^9, 3.8110499333613863`*^9, 
  3.811150782468829*^9, 3.811152890283012*^9, 3.811153185029909*^9, 
  3.81115577136878*^9, 3.811155919164733*^9, 3.811155992366003*^9, 
  3.811156076652321*^9, 3.811156116431382*^9, 3.8111565805593357`*^9, 
  3.811156960370908*^9, 3.811157288155129*^9, 3.8111573537598343`*^9, 
  3.811157397126419*^9, 3.811158238622685*^9, 3.81122913762145*^9},
 CellLabel->
  "Out[280]=",ExpressionUUID->"fe21293f-fdb9-4d4e-a315-fd8c5af787aa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Similar", " ", "to", " ", "above", " ", "but", " ", "for", " ", "the", 
     " ", "twist"}], "-", 
    RowBox[{"3", " ", "contribution", " ", 
     RowBox[{"(", 
      RowBox[{"wave", " ", "function"}], ")"}], " ", "that", " ", "appears", 
     " ", "in", " ", "the", " ", "vector", " ", "matrix", " ", 
     RowBox[{"element", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", "u"}], ")"}], 
     RowBox[{"Integrate", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Phi]", "[", "v", "]"}], 
        RowBox[{"1", "-", "v"}]], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", "0", ",", "u"}], "}"}]}], "]"}]}], "+", 
    RowBox[{"2", "u", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Phi]", "[", "v", "]"}], "v"], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", "u", ",", "1"}], "}"}]}], "]"}]}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.8110498684834013`*^9, 3.811049978771988*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"dc3b9fa3-98b7-4b4e-91ee-cb12790bc0de"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "6"}], " ", 
   RowBox[{"(", 
    RowBox[{"u", "-", "1"}], ")"}], " ", "u"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.8110499756408243`*^9, 3.811049979075534*^9}, 
   3.8111507828601913`*^9, 3.8111528906903687`*^9, 3.811153185254506*^9, 
   3.811155771596896*^9, 3.811155919374393*^9, 3.8111559926*^9, 
   3.811156076981431*^9, 3.811156116653028*^9, 3.811156581778034*^9, 
   3.811156960602306*^9, 3.8111572885370073`*^9, 3.811157354003352*^9, 
   3.811157397344404*^9, 3.811158238969057*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"50ea0517-d582-4e8d-812d-27c9a492435a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculation", " ", "of", " ", "integral", " ", "in", " ", "the", " ", 
    "matrix", " ", "element", " ", 
    SubscriptBox["\[Epsilon]", "\[Alpha]"], 
    RowBox[{
     SuperscriptBox["M", "\[Mu]\[Nu]\[Alpha]"], "."}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]Perp", "[", "u_", "]"}], ":=", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"\[Phi]", "[", "u", "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "[", "v", "]"}], "-", 
       RowBox[{"\[Phi]Perp", "[", "v", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"v", ",", "0", ",", "u"}], "}"}]}], "]"}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.811064123724058*^9, 3.81106424897701*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"7d9da512-8aa7-4745-8077-789f7e691a61"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["3", "2"]}], " ", 
   RowBox[{"(", 
    RowBox[{"u", "-", "1"}], ")"}], " ", "u", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "u"}], "-", "1"}], ")"}]}], TraditionalForm]], "Output",\

 CellChangeTimes->{{3.8110642285102463`*^9, 3.811064249317753*^9}, 
   3.8111507830118027`*^9, 3.8111528908379383`*^9, 3.8111531853888283`*^9, 
   3.8111557728372307`*^9, 3.811155919624398*^9, 3.8111559927217216`*^9, 
   3.811156078067997*^9, 3.811156117714449*^9, 3.8111565820697803`*^9, 
   3.811156960732333*^9, 3.8111572901085453`*^9, 3.81115735511961*^9, 
   3.811157397439495*^9, 3.8111582399205437`*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"40811c6f-88a0-47dd-9ae6-dafe41a96e30"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Checking", " ", "for", " ", "gauge", " ", "invariance", " ", "of", " ", 
    "the", " ", "matrix", " ", 
    RowBox[{"element", " ", "--"}], " ", "rewriting", " ", "the", " ", "term",
     " ", "as", " ", "a", " ", 
    RowBox[{"derivative", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", "u_", "]"}], ":=", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"2", "u"}], "-", "1"}], "4"], 
      RowBox[{"\[Phi]", "[", "u", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Integrand", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", 
            RowBox[{
             RowBox[{"q1Sq", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "u"}], ")"}], "2"]}], "+", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", "q2Sq"}], "-", 
             RowBox[{"2", "u", 
              RowBox[{"(", 
               RowBox[{"1", "-", "u"}], ")"}], "q1q2"}]}]], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[CapitalPhi]", "[", "u", "]"}], "+", 
               RowBox[{"u", " ", 
                RowBox[{"\[Phi]Perp", "[", "u", "]"}]}]}], ")"}], "-", 
             RowBox[{
              FractionBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"q1Sq", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "u"}], ")"}]}], "-", 
                 RowBox[{"u", " ", "q1q2"}]}], ")"}], 
               RowBox[{"2", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"q1Sq", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "-", "u"}], ")"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["u", "2"], " ", "q2Sq"}], "-", 
                  RowBox[{"2", "u", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", "u"}], ")"}], "q1q2"}]}], ")"}]}]], 
              RowBox[{"\[Phi]", "[", "u", "]"}]}]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{"q1q2", "\[Rule]", 
            FractionBox[
             RowBox[{"pSq", "-", "q1Sq", "-", "q2Sq"}], "2"]}], "}"}]}], "//",
          "FullSimplify"}], "//", "ExpandAll"}], "//", 
       RowBox[{"FullSimplify", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"Integrand", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"pSq", "\[Rule]", 
              SuperscriptBox["p", "2"]}], ",", 
             RowBox[{"q1Sq", "\[Rule]", 
              SuperscriptBox["q1", "2"]}], ",", 
             RowBox[{"q2Sq", "\[Rule]", 
              SuperscriptBox["q2", "2"]}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"u", ",", "0", ",", "1"}], "}"}]}], "]"}]}]}], "//", 
      "FullSimplify"}]}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Int", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"q1", 
               RowBox[{"(", 
                RowBox[{"1", "-", "u"}], ")"}]}], "-", 
              RowBox[{"u", " ", "q2"}]}], ")"}], "2"]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[CapitalPhi]", "[", "u", "]"}], "+", 
              RowBox[{"u", " ", 
               RowBox[{"\[Phi]Perp", "[", "u", "]"}]}]}], ")"}], "-", 
            RowBox[{
             FractionBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["q1", "2"], 
                 RowBox[{"(", 
                  RowBox[{"1", "-", "u"}], ")"}]}], "-", 
                RowBox[{"u", " ", "q1", "*", "q2"}]}], ")"}], 
              RowBox[{"2", "*", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"q1", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", "u"}], ")"}]}], "-", 
                  RowBox[{"u", " ", "q2"}]}], ")"}], "2"]}]], 
             RowBox[{"\[Phi]", "[", "u", "]"}]}]}], ")"}]}], ",", "u"}], 
        "]"}], "//", "FullSimplify"}], "//", "ExpandAll"}], "//", 
     "FullSimplify"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Int", "/.", 
       RowBox[{"{", 
        RowBox[{"u", "\[Rule]", " ", "1"}], "}"}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{"Int", "/.", 
       RowBox[{"{", 
        RowBox[{"u", "\[Rule]", " ", "0"}], "}"}]}], ")"}]}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Cross", "-", 
     RowBox[{"check", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Der", "=", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"3", 
         SuperscriptBox["u", "2"], 
         RowBox[{"(", 
          RowBox[{"u", "-", "1"}], ")"}]}], 
        RowBox[{"2", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"q1", 
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}]}], "-", 
            RowBox[{"u", " ", "q2"}]}], ")"}], "2"]}]], ",", "u"}], "]"}], "//",
      "FullSimplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Int", "-", 
     FractionBox[
      RowBox[{"3", 
       SuperscriptBox["u", "2"], 
       RowBox[{"(", 
        RowBox[{"u", "-", "1"}], ")"}]}], 
      RowBox[{"2", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"q1", 
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}]}], "-", 
          RowBox[{"u", " ", "q2"}]}], ")"}], "2"]}]]}], "//", 
    "FullSimplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Der", "-", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"q1", 
            RowBox[{"(", 
             RowBox[{"1", "-", "u"}], ")"}]}], "-", 
           RowBox[{"u", " ", "q2"}]}], ")"}], "2"]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[CapitalPhi]", "[", "u", "]"}], "+", 
           RowBox[{"u", " ", 
            RowBox[{"\[Phi]Perp", "[", "u", "]"}]}]}], ")"}], "-", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["q1", "2"], 
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}]}], "-", 
            RowBox[{"u", " ", "q1", "*", "q2"}]}], 
           RowBox[{"2", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"q1", 
                RowBox[{"(", 
                 RowBox[{"1", "-", "u"}], ")"}]}], "-", 
               RowBox[{"u", " ", "q2"}]}], ")"}], "2"]}]], 
          RowBox[{"\[Phi]", "[", "u", "]"}]}]}], ")"}]}], ")"}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.811148780209237*^9, 3.811148820378585*^9}, {
   3.811148853367361*^9, 3.811148884549296*^9}, {3.81114893161119*^9, 
   3.811148960955348*^9}, {3.811149616196796*^9, 3.811149770146018*^9}, {
   3.811149813067531*^9, 3.8111498466218033`*^9}, {3.811149878414777*^9, 
   3.811149900218643*^9}, {3.811149973094038*^9, 3.8111499980295973`*^9}, {
   3.8111507233833313`*^9, 3.811150754162253*^9}, {3.811150812602335*^9, 
   3.811150815246381*^9}, {3.8111508614648952`*^9, 3.811150939592457*^9}, {
   3.811150998181121*^9, 3.811151022051255*^9}, {3.81115108203673*^9, 
   3.8111511848986073`*^9}, {3.811151234997847*^9, 3.811151235511512*^9}, {
   3.81115151031137*^9, 3.811151521299354*^9}, {3.811152817410771*^9, 
   3.811152874713602*^9}, {3.811152933324089*^9, 3.811152971098768*^9}, {
   3.811153004842464*^9, 3.811153089562022*^9}, {3.811153124756546*^9, 
   3.811153126853848*^9}, 3.8111533287373943`*^9, {3.811154548010454*^9, 
   3.811154617472411*^9}, {3.811155665505747*^9, 3.811155670655251*^9}, {
   3.8111558984498777`*^9, 3.811155905592668*^9}, {3.8111559705485477`*^9, 
   3.81115597969938*^9}, {3.811156062753242*^9, 3.81115610537731*^9}, {
   3.8111561465304337`*^9, 3.811156160897297*^9}, 3.811156264474081*^9, {
   3.811156567554949*^9, 3.8111565711284447`*^9}, {3.811156791858645*^9, 
   3.811156803777006*^9}, {3.811156899075739*^9, 3.8111569475102873`*^9}, {
   3.811157038890188*^9, 3.811157057059532*^9}, {3.811157128704136*^9, 
   3.811157139889844*^9}, {3.811157267152092*^9, 3.811157304062292*^9}, {
   3.8111573373382874`*^9, 3.811157341687964*^9}, {3.8111573719501762`*^9, 
   3.811157387387233*^9}, {3.811157424543956*^9, 3.811157469159815*^9}, {
   3.811157862263216*^9, 3.8111579455874043`*^9}, {3.811157994465897*^9, 
   3.8111580592025547`*^9}, {3.811158119530714*^9, 3.8111581376765127`*^9}, {
   3.811158184508924*^9, 3.811158293521538*^9}, {3.811158334969864*^9, 
   3.811158357844851*^9}, {3.8111584096495857`*^9, 3.8111584219602413`*^9}, {
   3.811485900743823*^9, 3.811485918599245*^9}, {3.811485950193696*^9, 
   3.811485954258353*^9}},ExpressionUUID->"2adc9422-daf3-40ee-bf47-\
c6a9376dabf6"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["q1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"q2", "-", "q1"}], ")"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["u", "3"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q1", "+", "q2"}], ")"}], "3"]}], "-", 
    RowBox[{"6", " ", "q1", " ", 
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q1", "+", "q2"}], ")"}], "2"]}], "+", 
    RowBox[{"6", " ", "q1", " ", "u", " ", 
     RowBox[{"(", 
      RowBox[{"q1", "-", "q2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"q1", "+", "q2"}], ")"}]}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "+", "q2"}], ")"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"q1", " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "1"}], ")"}]}], "+", 
       RowBox[{"q2", " ", "u"}]}], ")"}], "2"]}]], TraditionalForm]], "Output",\

 CellChangeTimes->{3.811158358862657*^9, 3.811158425253495*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"e19f262c-21a7-4d42-911a-146bc3a51934"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.811158358862657*^9, 3.811158425256235*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"ec0146f7-cd2f-4280-96ca-f74775d4852f"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"3", " ", "u", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"q1", " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", "2"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"u", "-", "1"}], ")"}]}], "+", 
      RowBox[{"q2", " ", 
       SuperscriptBox["u", "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"q1", " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "1"}], ")"}]}], "+", 
       RowBox[{"q2", " ", "u"}]}], ")"}], "3"]}]], TraditionalForm]], "Output",\

 CellChangeTimes->{3.811158358862657*^9, 3.811158425304701*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"5a6f1194-ca0d-4609-8f53-d6a6b6a1d4a8"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{"q1", "-", "q2"}], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q1", "+", "q2"}], ")"}], "3"]}]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.811158358862657*^9, 3.811158425307358*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"35e7ad14-acaa-4944-8f76-0695f0022412"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.811158358862657*^9, 3.811158425314517*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"49aac906-76a1-42c3-9be3-dd8a3f3fde08"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellLabel->"In[29]:=",ExpressionUUID->"2256c081-19c2-4bec-b5f2-6a56dbf09c26"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"FeynCalc \"\>", "Text",
     StripOnInput->False,
     FontWeight->Bold], "\[InvisibleSpace]", 
    StyleBox["\<\"9.2.0. For help, use the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"documentation", " ", "center"}],
       BaseStyle->"Link",
       ButtonData:>"paclet:FeynCalc/",
       ButtonNote->"paclet:FeynCalc/"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\", check out the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["wiki",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" or write to the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"mailing", " ", 
        RowBox[{"list", "."}]}],
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["http://www.feyncalc.org/forum/"], None},
       ButtonNote->"http://www.feyncalc.org/forum/"],
      DisplayForm], "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["FeynCalc ", "Text", Bold], 
    Style["9.2.0. For help, use the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "documentation center", BaseStyle -> "Link", ButtonData :> 
       "paclet:FeynCalc/", ButtonNote -> "paclet:FeynCalc/"]], "Text"], 
    Style[", check out the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["wiki", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" or write to the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["mailing list.", ButtonData :> {
         URL["http://www.feyncalc.org/forum/"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> "http://www.feyncalc.org/forum/"]], "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.811162135560899*^9},
 CellLabel->
  "During evaluation of \
In[29]:=",ExpressionUUID->"1c62b468-a821-4c52-a34d-48da9d739e6d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"See also the supplied \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"examples", "."}],
       BaseStyle->"Hyperlink",
       ButtonFunction:>SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]],
       Evaluator->Automatic,
       Method->"Preemptive"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" If you use FeynCalc in your research, please cite\"\>", 
     "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["See also the supplied ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "examples.", BaseStyle -> "Hyperlink", ButtonFunction :> SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]], Evaluator -> 
       Automatic, Method -> "Preemptive"]], "Text"], 
    Style[" If you use FeynCalc in your research, please cite", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.81116213557139*^9},
 CellLabel->
  "During evaluation of \
In[29]:=",ExpressionUUID->"cec6a4fa-87fc-4728-b2bf-94a2af5e698e"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, Comput. \
Phys. Commun., 207C, 432-444, 2016, arXiv:1601.01167\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.811162135573174*^9},
 CellLabel->
  "During evaluation of \
In[29]:=",ExpressionUUID->"dc27f9ac-3425-4358-b847-313865cce8f8"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] R. Mertig, M. B\[ODoubleDot]hm, and A. Denner, \
Comput. Phys. Commun., 64, 345-359, 1991.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.811162135575066*^9},
 CellLabel->
  "During evaluation of \
In[29]:=",ExpressionUUID->"311e510d-5fa1-480b-9937-bb24154a0ad5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Projecting", " ", "onto", " ", "the", " ", "BTT", " ", 
     RowBox[{"structures", ".", " ", "Note"}], " ", "that", " ", "the", " ", 
     "first", " ", "two", " ", "structures", " ", "can", " ", "be", " ", 
     "written", " ", "in", " ", "terms", " ", "of", " ", "the", " ", "others",
      " ", "by", " ", "use", " ", "of", " ", "the", " ", "SCHOUTEN", " ", 
     "identities", " ", 
     RowBox[{"(", 
      RowBox[{
      "this", " ", "will", " ", "only", " ", "be", " ", "done", " ", "at", 
       " ", "the", " ", "end"}], ")"}]}], ";", " ", 
    RowBox[{
     RowBox[{
     "the", " ", "third", " ", "structure", " ", "does", " ", "not", " ", 
      "contribute", " ", "to", " ", "physical", " ", "observables", " ", 
      "because", " ", "it", " ", "is", " ", "projected", " ", "to", " ", 
      "zero", " ", "when", " ", "contracted", " ", "with", " ", "the", " ", 
      "polarization", " ", "sum", " ", "of", " ", "axial"}], "-", 
     RowBox[{"vectors", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"T1", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Alpha]", ",", "\[Mu]", ",", "\[Beta]", ",", "\[Gamma]"}],
           "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q1", ",", "\[Beta]"}], "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q2", ",", "\[Gamma]"}], "]"}]}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Nu]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Alpha]", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Beta]"}], 
          "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q1", ",", "\[Beta]"}], "]"}]}], "]"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q2"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"T2", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Alpha]", ",", "\[Nu]", ",", "\[Beta]", ",", "\[Gamma]"}],
           "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q1", ",", "\[Beta]"}], "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q2", ",", "\[Gamma]"}], "]"}]}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Mu]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Alpha]", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Beta]"}], 
          "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q2", ",", "\[Beta]"}], "]"}]}], "]"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q2"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"T3", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"LeviCivita", "[", 
         RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Beta]", ",", "\[Gamma]"}], 
         "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"q1", ",", "\[Beta]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"q2", ",", "\[Gamma]"}], "]"}]}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{
        RowBox[{"q1", "+", "q2"}], ",", "\[Alpha]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T4", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"LeviCivita", "[", 
         RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Beta]", ",", "\[Gamma]"}], 
         "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"q1", ",", "\[Beta]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"q2", ",", "\[Gamma]"}], "]"}]}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{
        RowBox[{"q1", "-", "q2"}], ",", "\[Alpha]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T5", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Alpha]", ",", "\[Nu]", ",", "\[Beta]", ",", "\[Gamma]"}],
           "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q1", ",", "\[Beta]"}], "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q2", ",", "\[Gamma]"}], "]"}]}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q1", ",", "\[Mu]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Alpha]", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Beta]"}], 
          "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q2", ",", "\[Beta]"}], "]"}]}], "]"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q1"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"T6", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Alpha]", ",", "\[Mu]", ",", "\[Beta]", ",", "\[Gamma]"}],
           "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q1", ",", "\[Beta]"}], "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q2", ",", "\[Gamma]"}], "]"}]}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q2", ",", "\[Nu]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"LeviCivita", "[", 
          RowBox[{"\[Alpha]", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Beta]"}], 
          "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"q1", ",", "\[Beta]"}], "]"}]}], "]"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q2", ",", "q2"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Note", " ", "that", " ", "we", " ", "already", " ", "factored", " ", 
     "out", " ", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["q", "4"]], "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"M", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Alpha]_"}], "]"}], ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalPhi]", "[", "u", "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"LeviCivita", "[", 
             RowBox[{"\[Alpha]", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Beta]"}],
              "]"}], 
            RowBox[{"FV", "[", 
             RowBox[{
              RowBox[{"q1", "+", "q2"}], ",", "\[Beta]"}], "]"}], 
            RowBox[{"SP", "[", 
             RowBox[{"q", ",", "q"}], "]"}]}], "]"}], "-", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"LeviCivita", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Beta]", ",", "\[Gamma]"}],
              "]"}], 
            RowBox[{"FV", "[", 
             RowBox[{
              RowBox[{"q1", "-", "q2"}], ",", "\[Alpha]"}], "]"}], 
            RowBox[{"FV", "[", 
             RowBox[{"q1", ",", "\[Beta]"}], "]"}], 
            RowBox[{"FV", "[", 
             RowBox[{"q2", ",", "\[Gamma]"}], "]"}]}], "]"}]}], ")"}]}], "-", 
       
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"LeviCivita", "[", 
           RowBox[{"\[Alpha]", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Beta]"}], 
           "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], 
             RowBox[{"FV", "[", 
              RowBox[{"q1", ",", "\[Beta]"}], "]"}]}], "-", 
            RowBox[{"u", " ", 
             RowBox[{"FV", "[", 
              RowBox[{"q2", ",", "\[Beta]"}], "]"}]}]}], ")"}], 
          RowBox[{"SP", "[", 
           RowBox[{"q", ",", "q"}], "]"}]}], "]"}], 
        RowBox[{"\[Phi]Perp", "[", "u", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"\[Phi]", "[", "u", "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"LeviCivita", "[", 
             RowBox[{
             "\[Alpha]", ",", "\[Mu]", ",", "\[Beta]", ",", "\[Gamma]"}], 
             "]"}], 
            RowBox[{"(", 
             RowBox[{"FV", "[", 
              RowBox[{"q", ",", "\[Nu]"}], "]"}], ")"}], 
            RowBox[{"FV", "[", 
             RowBox[{"q1", ",", "\[Beta]"}], "]"}], 
            RowBox[{"FV", "[", 
             RowBox[{"q2", ",", "\[Gamma]"}], "]"}]}], "]"}], "+", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"LeviCivita", "[", 
             RowBox[{
             "\[Alpha]", ",", "\[Nu]", ",", "\[Beta]", ",", "\[Gamma]"}], 
             "]"}], 
            RowBox[{"(", 
             RowBox[{"FV", "[", 
              RowBox[{"q", ",", "\[Mu]"}], "]"}], ")"}], 
            RowBox[{"FV", "[", 
             RowBox[{"q1", ",", "\[Beta]"}], "]"}], 
            RowBox[{"FV", "[", 
             RowBox[{"q2", ",", "\[Gamma]"}], "]"}]}], "]"}]}], ")"}]}]}], 
      ")"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"SP", "[", 
       RowBox[{"q1", ",", "q2"}], "]"}], "=", 
      FractionBox[
       RowBox[{
        SuperscriptBox["mA", "2"], "-", 
        RowBox[{"SP", "[", 
         RowBox[{"q1", ",", "q1"}], "]"}], "-", 
        RowBox[{"SP", "[", 
         RowBox[{"q2", ",", "q2"}], "]"}]}], "2"]}], ";"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"q", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "u"}], ")"}], "q1"}], "-", 
       RowBox[{"u", " ", "q2"}]}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"ClearScalarProducts", ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "q", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q", ",", "q1"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "u"}], ")"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q1"}], "]"}]}], "-", 
      RowBox[{"u", " ", 
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q2"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q", ",", "q2"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "u"}], ")"}], 
       RowBox[{"SP", "[", 
        RowBox[{"q1", ",", "q2"}], "]"}]}], "-", 
      RowBox[{"u", " ", 
       RowBox[{"SP", "[", 
        RowBox[{"q2", ",", "q2"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"b", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"c", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"d", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"e", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"f", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}]}], "\[Equal]", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
          RowBox[{"T1", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], "]"}]}],
        "&&", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"b", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"c", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"d", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"e", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"f", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}]}], "\[Equal]", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
          RowBox[{"T2", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], "]"}]}],
        "&&", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"b", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"c", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"d", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"e", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"f", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}]}], "\[Equal]", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
          RowBox[{"T3", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], "]"}]}],
        "&&", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"b", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"c", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"d", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"e", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"f", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}]}], "\[Equal]", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
          RowBox[{"T4", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], "]"}]}],
        "&&", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"b", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"c", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"d", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"e", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"f", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}]}], "\[Equal]", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
          RowBox[{"T5", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], "]"}]}],
        "&&", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T1", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"b", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T2", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"c", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T3", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"d", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T4", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"e", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T5", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}], "+", 
         RowBox[{"f", "*", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
            RowBox[{"T6", "[", 
             RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
           "]"}]}]}], "\[Equal]", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"M", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}], 
          RowBox[{"T6", "[", 
           RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]"}], "]"}]}], 
         "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], 
       "}"}]}], "]"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.810543802406384*^9, 3.8105438370707407`*^9}, 
   3.8105439161100388`*^9, {3.81054420579918*^9, 3.810544212362111*^9}, {
   3.810544251133698*^9, 3.81054427824727*^9}, {3.8105443987837353`*^9, 
   3.810544769937418*^9}, {3.810544817489812*^9, 3.810544863186887*^9}, {
   3.81054817047011*^9, 3.810548202908085*^9}, {3.810549852636469*^9, 
   3.810549853018675*^9}, {3.811162157194179*^9, 3.81116230510816*^9}, {
   3.811162441208262*^9, 3.811162456747653*^9}, {3.811162523853635*^9, 
   3.8111625527128763`*^9}, {3.811162651431814*^9, 3.811162665572194*^9}, {
   3.8111629908792763`*^9, 3.8111631274824867`*^9}, {3.811163170833846*^9, 
   3.811163317270831*^9}, {3.8111679937088633`*^9, 3.811168005985454*^9}, {
   3.811168096213963*^9, 3.811168096307295*^9}, {3.811168318936369*^9, 
   3.811168368250297*^9}, {3.81117048887136*^9, 3.811170539017969*^9}, {
   3.811170574259232*^9, 3.811170594422461*^9}, {3.811171029194635*^9, 
   3.8111710516053*^9}, {3.8111711009853077`*^9, 3.811171105506281*^9}, {
   3.811171147663365*^9, 3.811171208592811*^9}, {3.811171822412167*^9, 
   3.811171926044868*^9}, {3.811171965779133*^9, 3.811171986704514*^9}, {
   3.8111739318592463`*^9, 3.8111739373792257`*^9}, {3.8111739746903057`*^9, 
   3.811174009049818*^9}, {3.811174065234952*^9, 3.811174192026145*^9}, {
   3.811174997384095*^9, 3.811175151510378*^9}, {3.811175269557611*^9, 
   3.811175486860867*^9}, {3.81117562464355*^9, 3.811175679363874*^9}, {
   3.811221648160974*^9, 3.8112216495464067`*^9}, {3.8112224438494177`*^9, 
   3.811222457927094*^9}, {3.811224506165934*^9, 
   3.8112245220833197`*^9}},ExpressionUUID->"95349e27-62b9-45f6-8c61-\
3f72e70c653e"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "Solve","svars",
    "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
    379,7,20915407819503329052,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{
  3.811175490335273*^9, {3.811222449076098*^9, 3.811222461183771*^9}},
 CellLabel->
  "During evaluation of \
In[368]:=",ExpressionUUID->"76134b38-0fbf-4766-bfd5-dfa05b2f1f33"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"u", "-", "1"}], ")"}], " ", "u"}]}], ")"}]}]}], ",", 
     RowBox[{"d", "\[Rule]", 
      FractionBox[
       RowBox[{"a", "+", "b"}], "2"]}], ",", 
     RowBox[{"e", "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox[
           OverscriptBox[
            FormBox["q",
             TraditionalForm], "_"],
           TraditionalForm], "2"]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          FormBox[
           OverscriptBox[
            FormBox["q1",
             TraditionalForm], "_"],
           TraditionalForm], "2"]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["u", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"u", "-", "1"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           FormBox[
            OverscriptBox[
             FormBox["q1",
              TraditionalForm], "_"],
            TraditionalForm], 
           FormBox["\<\"\[CenterDot]\"\>",
            TraditionalForm], 
           FormBox[
            OverscriptBox[
             FormBox["q2",
              TraditionalForm], "_"],
            TraditionalForm]}], ")"}]}], 
        SuperscriptBox[
         FormBox[
          OverscriptBox[
           FormBox["q1",
            TraditionalForm], "_"],
          TraditionalForm], "2"]], "-", "a", "+", 
       RowBox[{"3", " ", "u", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"u", "-", "1"}], ")"}], "2"]}]}]}], ",", 
     RowBox[{"f", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"u", "-", "1"}], ")"}], "2"], " ", 
          SuperscriptBox[
           FormBox[
            OverscriptBox[
             FormBox["q",
              TraditionalForm], "_"],
            TraditionalForm], "2"]}], 
         RowBox[{"2", " ", 
          SuperscriptBox[
           FormBox[
            OverscriptBox[
             FormBox["q2",
              TraditionalForm], "_"],
            TraditionalForm], "2"]}]]}], "-", 
       FractionBox[
        RowBox[{"3", " ", "u", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"u", "-", "1"}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           FormBox[
            OverscriptBox[
             FormBox["q1",
              TraditionalForm], "_"],
            TraditionalForm], 
           FormBox["\<\"\[CenterDot]\"\>",
            TraditionalForm], 
           FormBox[
            OverscriptBox[
             FormBox["q2",
              TraditionalForm], "_"],
            TraditionalForm]}], ")"}]}], 
        SuperscriptBox[
         FormBox[
          OverscriptBox[
           FormBox["q2",
            TraditionalForm], "_"],
          TraditionalForm], "2"]], "-", "b", "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["u", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "1"}], ")"}]}]}]}]}], "}"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811168369867774*^9, {3.811170515369853*^9, 3.81117054055523*^9}, {
   3.8111705813311663`*^9, 3.811170595965334*^9}, {3.811171035373744*^9, 
   3.811171049722725*^9}, 3.811171167481266*^9, 3.811171213936564*^9, 
   3.811171929705237*^9, 3.811171994182129*^9, 3.811173963627387*^9, 
   3.8111740116520567`*^9, {3.811174114219035*^9, 3.811174127879636*^9}, 
   3.811174160637705*^9, {3.811174193564033*^9, 3.811174195827516*^9}, {
   3.811175482604197*^9, 3.811175490424952*^9}, {3.811222449188933*^9, 
   3.811222461317236*^9}},
 CellLabel->
  "Out[379]=",ExpressionUUID->"a7f79af2-c7a4-4e3e-bc79-08a1f250c3a1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Rewriting", " ", "of", " ", "the", " ", "form", " ", "factors", " ", 
     SubsuperscriptBox["F", 
      RowBox[{
       RowBox[{"x", "/", "2"}], "/", "3"}], "A"], 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["q", "1", "2"], ",", 
       SubsuperscriptBox["q", "2", "2"]}], ")"}], " ", "for", " ", "the", " ",
      "axial"}], "-", 
    RowBox[{
    "vector", " ", "mesons", " ", "by", " ", "using", " ", "integration", " ",
      "by", " ", 
     RowBox[{"parts", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Note", " ", "that", " ", "using", " ", "the", " ", "SCHOUTEN", " ", 
     "identities"}], ",", " ", 
    RowBox[{
    "we", " ", "have", " ", "to", " ", "subtract", " ", "some", " ", 
     "constants", " ", "from", " ", "the", " ", "above", " ", "c"}], ",", " ",
     "d", ",", " ", "e", ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"and", " ", 
       RowBox[{"f", ":", " ", "c"}]}], " ", "\[Rule]", " ", 
      RowBox[{"c", "-", 
       FractionBox["a", "2"], "+", 
       FractionBox["b", "2"]}]}], ";", " ", 
     RowBox[{"d", " ", "\[Rule]", " ", 
      RowBox[{"d", "-", 
       FractionBox["a", "2"], "-", 
       FractionBox["b", "c"]}]}], ";", " ", 
     RowBox[{"e", " ", "\[Rule]", " ", 
      RowBox[{"e", "+", "a"}]}], ";", " ", 
     RowBox[{"f", " ", "\[Rule]", " ", 
      RowBox[{"f", "+", "b"}]}], ";"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", " ", 
   RowBox[{"However", ",", " ", 
    RowBox[{
    "the", " ", "constant", " ", "c", " ", "has", " ", "to", " ", "be", " ", 
     "set", " ", "to", " ", "zero", " ", "because", " ", "the", " ", 
     "corresponding", " ", "structure", " ", "projects", " ", "to", " ", 
     "zero", " ", "in", " ", "any", " ", "physical", " ", 
     RowBox[{"observable", ".", " ", "The"}], " ", "constant", " ", "d", " ", 
     "cancels", " ", "at", " ", "the", " ", "\"\<working\>\"", " ", "order", 
     " ", "in", " ", 
     RowBox[{
      FractionBox["1", 
       SubsuperscriptBox["q", "i", "4"]], "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Note", " ", "that", " ", "there", " ", "is", " ", "no", " ", 
      "integration", " ", "left", " ", "for", " ", "the", " ", "first", " ", 
      "form", " ", "factor"}], ";", " ", "however"}], ",", " ", 
    RowBox[{
    "this", " ", "form", " ", "factor", " ", "corresponds", " ", "to", " ", 
     "the", " ", "constant", " ", "c"}], ",", " ", 
    RowBox[{
    "which", " ", "on", " ", "the", " ", "other", " ", "hand", " ", "belongs",
      " ", "to", " ", "the", " ", "third", " ", "structures", " ", "and", " ",
      "thus", " ", "projects", " ", "to", " ", "zero", " ", "in", " ", 
     "physical", " ", 
     RowBox[{"observables", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Num1", "[", "u_", "]"}], ":=", "1"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Den1", "[", "u_", "]"}], ":=", 
     FractionBox[
      RowBox[{
       RowBox[{"3", 
        SuperscriptBox["u", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", "u"}], ")"}], "2"], 
           SuperscriptBox["q1", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", "u", 
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], "q1", "*", "q2"}]}], ")"}]}], "-", 
       RowBox[{"6", 
        SuperscriptBox["u", "2"], 
        RowBox[{"(", 
         RowBox[{"u", "-", "1"}], ")"}], "q1", "*", "q2"}], "+", 
       RowBox[{"6", 
        SuperscriptBox["q1", "2"], "u", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"u", "-", "1"}], ")"}], "2"]}]}], 
      RowBox[{"2", 
       SuperscriptBox["q1", "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["q1", "2"], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", "u"}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"2", "u", 
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], "q1", "*", "q2"}]}], ")"}], 
        "2"]}]]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Integrate", "[", 
          RowBox[{
           RowBox[{"Num1", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
         RowBox[{"Den1", "[", "u", "]"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Integrate", "[", 
           RowBox[{
            RowBox[{"Num1", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
          RowBox[{"Den1", "[", "u", "]"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"Num1", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"Den1", "[", "u", "]"}], ",", "u"}], "]"}]}]}]}], "//", 
     RowBox[{
     "Simplify", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Num1P1", "[", "u_", "]"}], ":=", 
       RowBox[{"3", 
        SuperscriptBox["u", "2"]}]}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Den1P1", "[", "u_", "]"}], ":=", 
     FractionBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "u"}], ")"}], "2"], "q1Sq"}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", "q2Sq"}], "-", 
        RowBox[{"2", "u", 
         RowBox[{"(", 
          RowBox[{"1", "-", "u"}], ")"}], "q1q2"}]}], ")"}], 
      RowBox[{"2", "q1Sq", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"q1Sq", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", "u"}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", "q2Sq"}], "-", 
          RowBox[{"2", "u", 
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], "q1q2"}]}], ")"}], "2"]}]]}], ";",
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Num1P2", "[", "u_", "]"}], ":=", 
     RowBox[{
      RowBox[{"-", "6"}], 
      SuperscriptBox["u", "2"], 
      RowBox[{"(", 
       RowBox[{"u", "-", "1"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Den1P2", "[", "u_", "]"}], ":=", 
     FractionBox["q1q2", 
      RowBox[{"2", "q1Sq", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"q1Sq", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", "u"}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", "q2Sq"}], "-", 
          RowBox[{"2", "u", 
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], "q1q2"}]}], ")"}], "2"]}]]}], ";",
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Num1P3", "[", "u_", "]"}], ":=", 
     RowBox[{"6", "u", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"u", "-", "1"}], ")"}], "2"]}]}], ";", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"Den1P3", "[", "u_", "]"}], ":=", 
     FractionBox[
      RowBox[{"6", "q1Sq"}], 
      RowBox[{"2", "q1Sq", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"q1Sq", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", "u"}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", "q2Sq"}], "-", 
          RowBox[{"2", "u", 
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], "q1q2"}]}], ")"}], "2"]}]]}], ";",
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"S1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Integrate", "[", 
            RowBox[{
             RowBox[{"Num1P1", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
           RowBox[{"Den1P1", "[", "u", "]"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Integrate", "[", 
            RowBox[{
             RowBox[{"Num1P1", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
           RowBox[{"Den1P1", "[", "u", "]"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", 
       RowBox[{
       "Simplify", "\[IndentingNewLine]", "\[IndentingNewLine]", "P1"}]}], 
      "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Integrate", "[", 
          RowBox[{
           RowBox[{"Num1P1", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"Den1P1", "[", "u", "]"}], ",", "u"}], "]"}]}], "//", 
        RowBox[{
        "Simplify", "\[IndentingNewLine]", "\[IndentingNewLine]", "S2"}]}], 
       "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Integrate", "[", 
              RowBox[{
               RowBox[{"Num1P2", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
             RowBox[{"Den1P2", "[", "u", "]"}]}], "/.", 
            RowBox[{"{", 
             RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Integrate", "[", 
              RowBox[{
               RowBox[{"Num1P2", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
             RowBox[{"Den1P2", "[", "u", "]"}]}], "/.", 
            RowBox[{"{", 
             RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", 
         RowBox[{
         "Simplify", "\[IndentingNewLine]", "\[IndentingNewLine]", "P2"}]}], 
        "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Integrate", "[", 
            RowBox[{
             RowBox[{"Num1P2", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"Den1P2", "[", "u", "]"}], ",", "u"}], "]"}]}], "//", 
          RowBox[{
          "Simplify", "\[IndentingNewLine]", "\[IndentingNewLine]", "S3"}]}], 
         "=", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Integrate", "[", 
                RowBox[{
                 RowBox[{"Num1P3", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
               RowBox[{"Den1P3", "[", "u", "]"}]}], "/.", 
              RowBox[{"{", 
               RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Integrate", "[", 
                RowBox[{
                 RowBox[{"Num1P3", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
               RowBox[{"Den1P3", "[", "u", "]"}]}], "/.", 
              RowBox[{"{", 
               RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", 
           RowBox[{
           "Simplify", "\[IndentingNewLine]", "\[IndentingNewLine]", "P3"}]}],
           "=", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Integrate", "[", 
               RowBox[{
                RowBox[{"Num1P3", "[", "u", "]"}], ",", "u"}], "]"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{
                RowBox[{"Den1P3", "[", "u", "]"}], ",", "u"}], "]"}]}], "//", 
             
             RowBox[{"Simplify", "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"S1", "+", "S2", "+", "S3"}], "/.", 
               RowBox[{"{", 
                RowBox[{"q1q2", "\[Rule]", 
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["mA", "2"], "-", "q1Sq", "-", "q2Sq"}], 
                  "2"]}], "}"}]}]}]}], "//", 
            RowBox[{
             RowBox[{
              RowBox[{"Simplify", "\[IndentingNewLine]", "P1"}], "+", "P2", 
              "+", "P3"}], "/.", 
             RowBox[{"{", 
              RowBox[{"q1q2", "\[Rule]", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["mA", "2"], "-", "q1Sq", "-", "q2Sq"}], 
                "2"]}], "}"}]}]}], "//", "Simplify"}]}]}]}]}]}]}]}], 
   "\[IndentingNewLine]", "*)"}]}]], "Input",
 CellChangeTimes->{{3.810549856017008*^9, 3.8105500251570683`*^9}, {
   3.810550084727529*^9, 3.810550108034891*^9}, {3.810550900740589*^9, 
   3.81055090338063*^9}, {3.810550987301873*^9, 3.810551012952799*^9}, 
   3.810561018335664*^9, {3.810561060175823*^9, 3.810561080392806*^9}, {
   3.811171351529481*^9, 3.811171357558799*^9}, {3.8111716686480227`*^9, 
   3.811171679296084*^9}, {3.8111720425540657`*^9, 3.8111720999685907`*^9}, {
   3.811172356908124*^9, 3.8111723813064337`*^9}, {3.811172411689489*^9, 
   3.811172542624543*^9}, {3.8111726373497057`*^9, 3.811172771967883*^9}, {
   3.811172910906073*^9, 3.8111729368666897`*^9}, 3.811174274491961*^9, {
   3.811174488099959*^9, 3.811174488776195*^9}, {3.811174789444446*^9, 
   3.8111748064221888`*^9}, 3.811221725704224*^9, {3.8112218799765177`*^9, 
   3.811222010021346*^9}, {3.811222251152019*^9, 3.811222257461726*^9}, {
   3.811222313897718*^9, 3.811222376695256*^9}, {3.811222677727152*^9, 
   3.811222703661592*^9}, {3.811222939891799*^9, 3.8112229635886917`*^9}, {
   3.8112229958821173`*^9, 3.811222999548613*^9}, {3.811224008013259*^9, 
   3.8112240082163887`*^9}, {3.8112241220704536`*^9, 3.811224125355967*^9}, {
   3.811224159582223*^9, 3.8112241774591837`*^9}, {3.8112242350721607`*^9, 
   3.811224240444089*^9}, {3.811224285130765*^9, 3.811224326211273*^9}, {
   3.81122437461309*^9, 3.811224488740128*^9}, {3.811224575084434*^9, 
   3.811224652201297*^9}, {3.81122472790376*^9, 3.811224789635339*^9}, {
   3.8112248823566637`*^9, 3.8112249228221817`*^9}, {3.8112249756603127`*^9, 
   3.811224995425809*^9}, {3.811225039633945*^9, 3.811225188917656*^9}, {
   3.8112252586798267`*^9, 3.811225296430283*^9}, {3.811225356881543*^9, 
   3.811225479745792*^9}, {3.8112255163671618`*^9, 3.811225527703649*^9}, 
   3.81122556262278*^9, {3.8112256291977262`*^9, 3.811225630256703*^9}, {
   3.8112257049551287`*^9, 3.811225740833559*^9}, {3.811225791338002*^9, 
   3.811225796782699*^9}, {3.811229030684474*^9, 3.811229040856702*^9}, {
   3.811486017621398*^9, 3.8114860303472977`*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"44387abb-7efb-4ccf-9acb-17c540943442"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculating", " ", "the", " ", "integrals", " ", "for", " ", "some", " ", 
    "special", " ", 
    RowBox[{"cases", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", "u_", "]"}], ":=", 
     RowBox[{"6", "u", 
      RowBox[{"(", 
       RowBox[{"1", "-", "u"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F2A", "[", 
      RowBox[{"q1Sq_", ",", "q2Sq_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"u", " ", 
          RowBox[{"\[Phi]", "[", "u", "]"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u", " ", "q1Sq"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], "q2Sq"}], "-", 
            RowBox[{"u", 
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], 
             SuperscriptBox["mA", "2"]}]}], ")"}], "2"]], ",", "u"}], "]"}], "//",
       "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F3A", "[", 
      RowBox[{"q1Sq_", ",", "q2Sq_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "u"}], ")"}], " ", 
          RowBox[{"\[Phi]", "[", "u", "]"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u", " ", "q1Sq"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], "q2Sq"}], "-", 
            RowBox[{"u", 
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], 
             SuperscriptBox["mA", "2"]}]}], ")"}], "2"]], ",", "u"}], "]"}], "//",
       "Simplify"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.811493772650423*^9, 3.811493780530479*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"4bea8122-0fbc-48a2-8cad-cd3a6f4ed677"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "integrals", " ", 
    RowBox[{"F2A", "[", 
     RowBox[{"0", ",", "qSq"}], "]"}], " ", "and", " ", 
    RowBox[{"F3A", "[", 
     RowBox[{"qSq", ",", "0"}], "]"}], " ", "do", " ", "not", " ", 
    RowBox[{"converge", ".", " ", "This"}], " ", "is", " ", "just", " ", "as",
     " ", "an", " ", "extra", " ", "for", " ", "the", " ", "above", " ", 
    RowBox[{"calculations", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"F2A", "[", 
        RowBox[{"0", ",", "qSq"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"F2A", "[", 
        RowBox[{"0", ",", "qSq"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"F3A", "[", 
        RowBox[{"0", ",", "qSq"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"F3A", "[", 
        RowBox[{"0", ",", "qSq"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"F2A", "[", 
        RowBox[{"qSq", ",", "0"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"F2A", "[", 
        RowBox[{"qSq", ",", "0"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"F3A", "[", 
        RowBox[{"qSq", ",", "0"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"F3A", "[", 
        RowBox[{"qSq", ",", "0"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", 
    "Simplify"}]}]}]], "Input",
 CellLabel->
  "In[134]:=",ExpressionUUID->"07423eda-400f-44ab-bd20-780c9f07b41d"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", 
       SuperscriptBox["mA", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["mA", "2"], " ", "qSq"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["mA", "2"], " ", "qSq", " ", 
       RowBox[{"log", "(", 
        RowBox[{"-", "qSq"}], ")"}]}], "+", 
      RowBox[{"qSq", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["mA", "2"]}], "-", "qSq"}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{
         SuperscriptBox["mA", "2"], "-", "qSq"}], ")"}]}], "+", 
      RowBox[{"\[Infinity]", " ", 
       SuperscriptBox[
        TemplateBox[{"mA"},
         "Sign"], "4"]}], "+", 
      RowBox[{
       SuperscriptBox["qSq", "2"], " ", 
       RowBox[{"log", "(", 
        RowBox[{"-", "qSq"}], ")"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["mA", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["mA", "2"], "-", "qSq"}], ")"}], "2"]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.811493683405014*^9, 3.81149379430584*^9},
 CellLabel->
  "Out[134]=",ExpressionUUID->"e09c7bdd-1dba-40ca-a1f0-b281c9cf0c8d"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["mA", "2"], 
       RowBox[{"qSq", "-", 
        SuperscriptBox["mA", "2"]}]], "+", 
      RowBox[{"log", "(", 
       RowBox[{"qSq", "-", 
        SuperscriptBox["mA", "2"]}], ")"}], "-", 
      RowBox[{"log", "(", "qSq", ")"}]}], ")"}]}], 
   SuperscriptBox["mA", "4"]], TraditionalForm]], "Output",
 CellChangeTimes->{3.811493683405014*^9, 3.8114937943625793`*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"87e86c3a-2854-46fd-ab5c-2537178794c0"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["mA", "2"], 
       RowBox[{"qSq", "-", 
        SuperscriptBox["mA", "2"]}]], "+", 
      RowBox[{"log", "(", 
       RowBox[{"qSq", "-", 
        SuperscriptBox["mA", "2"]}], ")"}], "-", 
      RowBox[{"log", "(", "qSq", ")"}]}], ")"}]}], 
   SuperscriptBox["mA", "4"]], TraditionalForm]], "Output",
 CellChangeTimes->{3.811493683405014*^9, 3.811493794406794*^9},
 CellLabel->
  "Out[136]=",ExpressionUUID->"ee1aa2aa-d93c-40ef-baa7-1428854a30e4"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["\[Infinity]", 
    SuperscriptBox[
     TemplateBox[{RowBox[{
         SuperscriptBox["mA", "2"], "-", "qSq"}]},
      "Sign"], "2"]], "+", 
   FractionBox[
    RowBox[{"6", " ", "qSq", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"qSq", "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["mA", "2"]}]}], ")"}], " ", 
        RowBox[{"log", "(", "qSq", ")"}]}], "-", 
       SuperscriptBox["mA", "2"], "+", "qSq"}], ")"}]}], 
    RowBox[{
     SuperscriptBox["mA", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["mA", "2"], "-", "qSq"}], ")"}], "2"]}]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.811493683405014*^9, 3.8114937945500193`*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"1aa7ad75-feb4-4c17-a6c3-bd2e1b26ac09"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"The", " ", "logarithmic", " ", "end"}], "-", 
    RowBox[{
    "point", " ", "singularity", " ", "that", " ", "is", " ", "responsible", 
     " ", "for", " ", 
     RowBox[{"e", ".", "g", ".", " ", "the"}], " ", "convergence"}], "-", 
    RowBox[{"behavior", " ", "of", " ", 
     SubscriptBox["F", "2"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"0", ",", 
        SuperscriptBox["q", "2"]}], ")"}], "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Int", "=", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"u", " ", 
        RowBox[{"\[Phi]", "[", "u", "]"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], "q2Sq"}], "-", 
          RowBox[{"u", 
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], 
           SuperscriptBox["mA", "2"]}]}], ")"}], "2"]], ",", "u"}], "]"}], "//",
     "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.811229680354911*^9, 3.81122968583235*^9}, {
  3.811229721224648*^9, 3.8112297685445757`*^9}, {3.811229971591371*^9, 
  3.811229975459592*^9}, {3.811230023614423*^9, 3.8112300284356403`*^9}, {
  3.811489665816902*^9, 3.811489692461772*^9}, {3.8114920467814407`*^9, 
  3.811492164566286*^9}, {3.811493804560165*^9, 3.8114938048311768`*^9}},
 CellLabel->
  "In[140]:=",ExpressionUUID->"9424bee5-cc65-46cf-a622-40210ef4b269"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"q2Sq", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"q2Sq", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mA", "2"], "-", "q2Sq"}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["mA", "2"]}], "-", "q2Sq"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["mA", "2"], " ", "u"}], "-", "q2Sq"}], ")"}], 
           " ", 
           RowBox[{"log", "(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["mA", "2"], " ", "u"}], "-", "q2Sq"}], ")"}]}]}],
          ")"}]}], "+", 
       RowBox[{
        RowBox[{"log", "(", 
         RowBox[{"u", "-", "1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["mA", "6"], " ", "u"}], "-", 
          RowBox[{
           SuperscriptBox["mA", "4"], " ", "q2Sq"}]}], ")"}]}]}], ")"}]}], 
    RowBox[{
     SuperscriptBox["mA", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["mA", "2"], "-", "q2Sq"}], ")"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["mA", "2"], " ", "u"}], "-", "q2Sq"}], ")"}]}]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.811492114785932*^9, 3.811492164880958*^9}, {
  3.811493796791046*^9, 3.811493805131155*^9}},
 CellLabel->
  "Out[140]=",ExpressionUUID->"bfacced3-364e-4995-8b27-611a2bb66f2d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary of the BL Scaling", "Section",
 CellChangeTimes->{{3.8112353276646976`*^9, 3.811235332265016*^9}, {
  3.811486176032073*^9, 3.811486182405217*^9}, {3.81148962406885*^9, 
  3.8114896305979557`*^9}},ExpressionUUID->"85dd1ba1-a9ba-49dd-a4ba-\
c54872449eca"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Pseudoscalars", "."}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", "u_", "]"}], ":=", 
     RowBox[{"6", "u", 
      RowBox[{"(", 
       RowBox[{"1", "-", "u"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntPS", "=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"\[Phi]", "[", "u", "]"}], 
         RowBox[{
          RowBox[{"u", " ", 
           SuperscriptBox["q1", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], 
           SuperscriptBox["q2", "2"]}], "-", 
          RowBox[{"u", 
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], 
           SuperscriptBox["mP", "2"]}]}]], ",", "u"}], "]"}], "//", 
      "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntPSMZero", "=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"\[Phi]", "[", "u", "]"}], 
         RowBox[{
          RowBox[{"u", " ", 
           SuperscriptBox["q1", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], 
           SuperscriptBox["q2", "2"]}]}]], ",", "u"}], "]"}], "//", 
      "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"IntPSMZero", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
        RowBox[{"(", 
         RowBox[{"IntPSMZero", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", 
       "Simplify"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q1", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "+", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}], ",", 
       RowBox[{"q2", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}]}], "}"}]}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.811235344557877*^9, 3.811235384021063*^9}, {
  3.811235462688898*^9, 3.811235481105685*^9}, {3.811235551235105*^9, 
  3.811235565469314*^9}, {3.811235596602333*^9, 3.811235656863371*^9}, {
  3.811235725480976*^9, 3.811235745715186*^9}, {3.811236284024849*^9, 
  3.811236303291975*^9}, {3.811236375390608*^9, 3.811236379479154*^9}, {
  3.811236411126959*^9, 3.8112364761607723`*^9}, {3.811237325993422*^9, 
  3.811237414011441*^9}, {3.811492183424218*^9, 3.811492186070346*^9}, {
  3.811492278855522*^9, 3.811492310025728*^9}, {3.811492525170862*^9, 
  3.811492603769009*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"00acf006-8fd7-4b05-aa42-bfbc23c12a09"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "-", "1"}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{"QSq", " ", 
        RowBox[{"(", 
         RowBox[{"\[Omega]", "-", "1"}], ")"}]}], ")"}]}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Omega]", "2"], "-", "1"}], ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{
       RowBox[{"-", "QSq"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Omega]", "+", "1"}], ")"}]}], ")"}]}], "+", 
    RowBox[{"6", " ", "\[Omega]"}]}], 
   RowBox[{"4", " ", "QSq", " ", 
    SuperscriptBox["\[Omega]", "3"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811235397887452*^9, {3.811235463667054*^9, 3.811235481476796*^9}, 
   3.811235746090228*^9, {3.811236285899613*^9, 3.811236304258864*^9}, 
   3.811236380125355*^9, {3.811236454480853*^9, 3.811236480107687*^9}, {
   3.8112373674119177`*^9, 3.811237414361717*^9}, {3.811492284129421*^9, 
   3.811492310319826*^9}, {3.81149256695251*^9, 3.811492604241827*^9}},
 CellLabel->
  "Out[108]=",ExpressionUUID->"a1196eb5-d2f6-4f67-af0b-79a0b111de50"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Scalars", "."}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"IntS1", "=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"3", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "u"}], "-", "1"}], ")"}], "2"], 
          RowBox[{"\[Phi]", "[", "u", "]"}]}], 
         RowBox[{
          RowBox[{"u", " ", 
           SuperscriptBox["q1", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "u"}], ")"}], 
           SuperscriptBox["q2", "2"]}]}]], ",", "u"}], "]"}], "//", 
      "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntS2", "=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"3", "u", 
          RowBox[{"(", 
           RowBox[{"1", "-", "u"}], ")"}], 
          RowBox[{"\[Phi]", "[", "u", "]"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u", " ", 
             SuperscriptBox["q1", "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], 
             SuperscriptBox["q2", "2"]}]}], ")"}], "2"]], ",", "u"}], "]"}], "//",
       "Simplify"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"IntS1", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
        RowBox[{"(", 
         RowBox[{"IntS1", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", 
       "Simplify"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q1", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "+", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}], ",", 
       RowBox[{"q2", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}]}], "}"}]}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"IntS2", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
        RowBox[{"(", 
         RowBox[{"IntS2", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", 
       "Simplify"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q1", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "+", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}], ",", 
       RowBox[{"q2", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}]}], "}"}]}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.811492339107942*^9, 3.811492492528287*^9}, {
  3.811493100250718*^9, 3.811493107099275*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"e327252a-2773-4c6f-83b5-efd8bf89a9f6"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{"9", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "-", "1"}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{"QSq", " ", 
        RowBox[{"(", 
         RowBox[{"\[Omega]", "-", "1"}], ")"}]}], ")"}]}]}], "+", 
    RowBox[{"9", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Omega]", "2"], "-", "1"}], ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{
       RowBox[{"-", "QSq"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Omega]", "+", "1"}], ")"}]}], ")"}]}], "+", 
    RowBox[{"6", " ", "\[Omega]", " ", 
     RowBox[{"(", 
      RowBox[{"3", "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], 
   RowBox[{"4", " ", "QSq", " ", 
    SuperscriptBox["\[Omega]", "5"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.811492456933894*^9, 3.811492493312858*^9, 
  3.811493107741955*^9},
 CellLabel->
  "Out[111]=",ExpressionUUID->"93baa218-bfb9-4886-804b-74295f2e2d28"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{"9", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "-", "1"}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{"QSq", " ", 
        RowBox[{"(", 
         RowBox[{"\[Omega]", "-", "1"}], ")"}]}], ")"}]}]}], "+", 
    RowBox[{"9", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Omega]", "2"], "-", "1"}], ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{
       RowBox[{"-", "QSq"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Omega]", "+", "1"}], ")"}]}], ")"}]}], "+", 
    RowBox[{"6", " ", "\[Omega]", " ", 
     RowBox[{"(", 
      RowBox[{"3", "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox["QSq", "2"], " ", 
    SuperscriptBox["\[Omega]", "5"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.811492456933894*^9, 3.811492493312858*^9, 
  3.811493107781575*^9},
 CellLabel->
  "Out[112]=",ExpressionUUID->"4ca9e11a-4896-49a4-bb26-a4a83f959abb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Axial", "-", 
    RowBox[{"Vectors", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"IntA1", "=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"u", " ", 
          RowBox[{"\[Phi]", "[", "u", "]"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u", " ", 
             SuperscriptBox["q1", "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], 
             SuperscriptBox["q2", "2"]}], "-", 
            RowBox[{"u", 
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], 
             SuperscriptBox["mA", "2"]}]}], ")"}], "2"]], ",", "u"}], "]"}], "//",
       "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntA2", "=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "u"}], ")"}], " ", 
          RowBox[{"\[Phi]", "[", "u", "]"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u", " ", 
             SuperscriptBox["q1", "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], 
             SuperscriptBox["q2", "2"]}], "-", 
            RowBox[{"u", 
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], 
             SuperscriptBox["mA", "2"]}]}], ")"}], "2"]], ",", "u"}], "]"}], "//",
       "Simplify"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntA1MZero", "=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"u", " ", 
          RowBox[{"\[Phi]", "[", "u", "]"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u", " ", 
             SuperscriptBox["q1", "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], 
             SuperscriptBox["q2", "2"]}]}], ")"}], "2"]], ",", "u"}], "]"}], "//",
       "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntA2MZero", "=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "u"}], ")"}], " ", 
          RowBox[{"\[Phi]", "[", "u", "]"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u", " ", 
             SuperscriptBox["q1", "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "u"}], ")"}], 
             SuperscriptBox["q2", "2"]}]}], ")"}], "2"]], ",", "u"}], "]"}], "//",
       "Simplify"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"IntA1MZero", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
        RowBox[{"(", 
         RowBox[{"IntA1MZero", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", 
       "Simplify"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q1", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "+", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}], ",", 
       RowBox[{"q2", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}]}], "}"}]}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"IntA2MZero", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
        RowBox[{"(", 
         RowBox[{"IntA2MZero", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", 
       "Simplify"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q1", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "+", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}], ",", 
       RowBox[{"q2", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}]}], "}"}]}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.811229109412582*^9, 3.811229260746475*^9}, {
  3.81122936977271*^9, 3.811229370132586*^9}, {3.8112298106082087`*^9, 
  3.8112298130055017`*^9}, {3.811229949243326*^9, 3.811229951040119*^9}, {
  3.81149219254797*^9, 3.811492198001631*^9}, {3.811492382225473*^9, 
  3.81149238273112*^9}, {3.8114936093826313`*^9, 3.811493751569634*^9}, {
  3.811493824059651*^9, 3.811493867356138*^9}},
 CellLabel->
  "In[141]:=",ExpressionUUID->"5b431a67-9a79-417e-8564-7c915ac229d2"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "+", 
        RowBox[{"2", " ", "\[Omega]"}], "-", "3"}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{"QSq", " ", 
        RowBox[{"(", 
         RowBox[{"\[Omega]", "-", "1"}], ")"}]}], ")"}]}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Omega]", "2"], "+", 
       RowBox[{"2", " ", "\[Omega]"}], "-", "3"}], ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{
       RowBox[{"-", "QSq"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Omega]", "+", "1"}], ")"}]}], ")"}]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{"3", "-", 
       RowBox[{"2", " ", "\[Omega]"}]}], ")"}], " ", "\[Omega]"}]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["QSq", "2"], " ", 
    SuperscriptBox["\[Omega]", "4"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811492386091565*^9, {3.811493688754105*^9, 3.8114937128606377`*^9}, 
   3.811493870704322*^9},
 CellLabel->
  "Out[145]=",ExpressionUUID->"52131f1a-524a-4a52-a19e-f3baaa051593"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Omega]", "2"], "-", 
         RowBox[{"2", " ", "\[Omega]"}], "-", "3"}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"QSq", " ", 
         RowBox[{"(", 
          RowBox[{"\[Omega]", "-", "1"}], ")"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Omega]", "2"]}], "+", 
         RowBox[{"2", " ", "\[Omega]"}], "+", "3"}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{
         RowBox[{"-", "QSq"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Omega]", "+", "1"}], ")"}]}], ")"}]}], "-", 
      RowBox[{"2", " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Omega]"}], "+", "3"}], ")"}]}]}], ")"}]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["QSq", "2"], " ", 
    SuperscriptBox["\[Omega]", "4"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811492386091565*^9, {3.811493688754105*^9, 3.8114937128606377`*^9}, 
   3.8114938707538033`*^9},
 CellLabel->
  "Out[146]=",ExpressionUUID->"6b39b050-8ed1-45cb-b023-28054a05a4e7"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison to Data for Axial-Vector Mesons", "Chapter",
 CellChangeTimes->{{3.811502716381221*^9, 3.811502723151168*^9}, {
  3.811502870474565*^9, 
  3.811502873631913*^9}},ExpressionUUID->"5c18aeeb-b910-4ef7-a7d3-\
407d0b0f4e68"],

Cell[CellGroupData[{

Cell["Asymptotic Limits", "Section",
 CellChangeTimes->{{3.811576679911365*^9, 
  3.811576691434148*^9}},ExpressionUUID->"49ea13c1-3006-4f86-a574-\
9c8a3d1d754c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "We", " ", "need", " ", "to", " ", "calculate", " ", "the", " ", "limits",
      " ", "of", " ", "the", " ", "asymmetry", " ", "functions", " ", "f", 
     RowBox[{"(", "w", ")"}], " ", "in", " ", "order", " ", "to", " ", 
     "obtain", " ", "the", " ", "symmetric", " ", "doubly"}], "-", 
    RowBox[{"virtual", " ", "and", " ", "singly"}], "-", 
    RowBox[{"virtual", " ", "form", " ", 
     RowBox[{"factors", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      FractionBox["3", 
       RowBox[{"4", 
        SuperscriptBox["x", "3"]}]], 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", "x"}], "+", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", "x"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "-", "x"}], ")"}]}], 
          RowBox[{"2", "x"}]], 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"1", "-", "x"}], 
           RowBox[{"1", "+", "x"}]], "]"}]}]}], ")"}]}], ",", 
     RowBox[{"x", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Alternative", ",", " ", 
     RowBox[{
      RowBox[{
      "where", " ", "it", " ", "is", " ", "now", " ", "easy", " ", "to", " ", 
       "comprehend", " ", "where", " ", "the", " ", "limit", " ", "above", 
       " ", "is", " ", "coming", " ", "from"}], ";", " ", 
      RowBox[{
       RowBox[{
       "namely", " ", "by", " ", "taylor", " ", "expanding", " ", "the", " ", 
        "logarithm", " ", "and", " ", "then", " ", "taking", " ", "the", " ", 
        "limit", " ", "x"}], " ", "\[Rule]", " ", "0."}]}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    FractionBox["3", 
     RowBox[{"4", 
      SuperscriptBox["x", "3"]}]], 
    RowBox[{"(", 
     RowBox[{"3", "-", 
      RowBox[{"2", "x"}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", "x"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}]}], 
        RowBox[{"2", "x"}]], 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"1", "-", "x"}], 
           RowBox[{"1", "+", "x"}]], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "5"}], "}"}]}], "]"}]}]}], ")"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Singly", "-", 
     RowBox[{"virtual", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      FractionBox["3", 
       RowBox[{"4", 
        SuperscriptBox["x", "3"]}]], 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", "x"}], "+", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", "x"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "-", "x"}], ")"}]}], 
          RowBox[{"2", "x"}]], 
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"1", "-", "x"}], 
           RowBox[{"1", "+", "x"}]], "]"}]}]}], ")"}]}], ",", 
     RowBox[{"x", "\[Rule]", "1"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Singly", "-", 
     RowBox[{
     "virtual", " ", "case", " ", "when", " ", "keeping", " ", "the", " ", 
      "axial"}], "-", 
     RowBox[{"vector", " ", 
      RowBox[{"mass", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"IntA1", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "1"}], "}"}]}], ")"}], "-", 
        RowBox[{"(", 
         RowBox[{"IntA1", "/.", 
          RowBox[{"{", 
           RowBox[{"u", "\[Rule]", "0"}], "}"}]}], ")"}]}], "//", 
       "Simplify"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q1", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "+", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}], ",", 
       RowBox[{"q2", "\[Rule]", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", "\[Omega]"}]], 
         SqrtBox["QSq"]}]}]}], "}"}]}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["mA", "4"], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["mA", "4"]}], "+", 
              RowBox[{"4", 
               SuperscriptBox["mA", "2"], "QSq"}], "-", 
              RowBox[{"4", 
               SuperscriptBox["QSq", "2"], 
               SuperscriptBox["x", "2"]}]}], ")"}], 
            RowBox[{"3", "/", "2"}]]}]]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["mA", "4"]}], "+", 
             RowBox[{"4", 
              SuperscriptBox["mA", "2"], "QSq"}], "-", 
             RowBox[{"4", 
              SuperscriptBox["QSq", "2"], 
              SuperscriptBox["x", "2"]}]}]], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], 
              SuperscriptBox["mA", "4"]}], "+", 
             RowBox[{"4", 
              SuperscriptBox["mA", "2"], "QSq", " ", "x"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["mA", "4"], "-", 
                RowBox[{"4", 
                 SuperscriptBox["mA", "2"], "QSq"}], "+", 
                RowBox[{"4", 
                 SuperscriptBox["QSq", "2"], 
                 SuperscriptBox["x", "2"]}]}], ")"}], 
              RowBox[{"Log", "[", 
               FractionBox[
                RowBox[{"1", "-", "x"}], 
                RowBox[{"1", "+", "x"}]], "]"}]}]}], ")"}]}], "+", 
          RowBox[{"6", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mA", "6"], "-", 
             RowBox[{"2", 
              SuperscriptBox["mA", "4"], "QSq", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", "x"}], "+", "1"}], ")"}]}], "+", 
             RowBox[{"12", 
              SuperscriptBox["mA", "2"], 
              SuperscriptBox["QSq", "2"], "x"}], "-", 
             RowBox[{"8", 
              SuperscriptBox["QSq", "3"], 
              SuperscriptBox["x", "3"]}]}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Series", "[", 
              RowBox[{
               RowBox[{"ArcTan", "[", 
                FractionBox[
                 RowBox[{
                  RowBox[{"2", "QSq", " ", "x"}], "-", 
                  SuperscriptBox["mA", "2"]}], 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["mA", "4"]}], "+", 
                   RowBox[{"4", 
                    SuperscriptBox["mA", "2"], "QSq"}], "-", 
                   RowBox[{"4", 
                    SuperscriptBox["QSq", "2"], 
                    SuperscriptBox["x", "2"]}]}]]], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "1", ",", "5"}], "}"}]}], "]"}], "-", 
             RowBox[{"Series", "[", 
              RowBox[{
               RowBox[{"ArcTan", "[", 
                FractionBox[
                 RowBox[{
                  RowBox[{"2", "QSq", " ", "x"}], "+", 
                  SuperscriptBox["mA", "2"]}], 
                 SqrtBox[
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["mA", "4"]}], "+", 
                   RowBox[{"4", 
                    SuperscriptBox["mA", "2"], "QSq"}], "-", 
                   RowBox[{"4", 
                    SuperscriptBox["QSq", "2"], 
                    SuperscriptBox["x", "2"]}]}]]], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "1", ",", "5"}], "}"}]}], "]"}]}], 
            ")"}]}]}], ")"}]}], "//", "Simplify"}], ",", 
      RowBox[{"x", "\[Rule]", "1"}]}], "]"}], "//", "Simplify"}]}]}]], "Input",\

 CellChangeTimes->{{3.811501482338793*^9, 3.811501547816408*^9}, {
   3.811502634248497*^9, 3.811502641028227*^9}, {3.811502739665127*^9, 
   3.811502911906344*^9}, {3.811503014377205*^9, 3.811503076897524*^9}, {
   3.811503156928047*^9, 3.81150319954597*^9}, {3.811503258215542*^9, 
   3.811503359565937*^9}, {3.811503455372718*^9, 3.811503464066681*^9}, 
   3.811503648117511*^9, {3.8115037185131073`*^9, 3.81150375022937*^9}, {
   3.81150386042929*^9, 3.81150386296692*^9}, {3.811504219579035*^9, 
   3.811504222208603*^9}, {3.811504260280604*^9, 3.811504276630762*^9}, {
   3.8115043820284348`*^9, 3.811504405828421*^9}, {3.811504442429941*^9, 
   3.811504445428747*^9}, {3.811505862790468*^9, 3.811505919132308*^9}, {
   3.811512047050293*^9, 3.8115120564367733`*^9}, {3.8115121053706427`*^9, 
   3.811512105619028*^9}, 3.811512244377365*^9, {3.811512275484232*^9, 
   3.811512319718738*^9}, {3.8115126245373096`*^9, 3.811512624845111*^9}, {
   3.811573033269086*^9, 3.811573033842013*^9}, {3.8115738382051477`*^9, 
   3.811573838295723*^9}},
 CellLabel->
  "In[397]:=",ExpressionUUID->"4eafd805-f5b6-4de2-a10b-5dc52c1ba3c6"],

Cell[BoxData[
 FormBox[
  FractionBox["1", "2"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811501548343588*^9, 3.811502642065413*^9, {3.811502904975367*^9, 
   3.811502912268366*^9}, {3.811503028704659*^9, 3.811503077180458*^9}, {
   3.811503168775702*^9, 3.811503199863674*^9}, {3.811503281745028*^9, 
   3.811503297169136*^9}, 3.8115033606385527`*^9, 3.811503466870008*^9, 
   3.811503648879196*^9, {3.811503719092285*^9, 3.81150375058223*^9}, 
   3.8115042253879423`*^9, 3.811504277238379*^9, {3.811504394795763*^9, 
   3.811504407703858*^9}, 3.811504448742634*^9, {3.811505870025113*^9, 
   3.8115059194371758`*^9}, 3.811505973879974*^9, 3.811512057150193*^9, 
   3.811512106346786*^9, {3.811512248931069*^9, 3.8115123200209227`*^9}, 
   3.811512625205599*^9, 3.8115730364841967`*^9, 3.811573838939999*^9},
 CellLabel->
  "Out[397]=",ExpressionUUID->"9ee07238-4b1f-4e3d-bf2b-ce5a62601f5a"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    FractionBox["1", "2"], "-", 
    FractionBox["x", "5"], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox["x", "2"], ")"}],
     SeriesData[$CellContext`x, 0, {}, 0, 2, 1],
     Editable->False]}],
   SeriesData[$CellContext`x, 0, {
     Rational[1, 2], 
     Rational[-1, 5]}, 0, 2, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811501548343588*^9, 3.811502642065413*^9, {3.811502904975367*^9, 
   3.811502912268366*^9}, {3.811503028704659*^9, 3.811503077180458*^9}, {
   3.811503168775702*^9, 3.811503199863674*^9}, {3.811503281745028*^9, 
   3.811503297169136*^9}, 3.8115033606385527`*^9, 3.811503466870008*^9, 
   3.811503648879196*^9, {3.811503719092285*^9, 3.81150375058223*^9}, 
   3.8115042253879423`*^9, 3.811504277238379*^9, {3.811504394795763*^9, 
   3.811504407703858*^9}, 3.811504448742634*^9, {3.811505870025113*^9, 
   3.8115059194371758`*^9}, 3.811505973879974*^9, 3.811512057150193*^9, 
   3.811512106346786*^9, {3.811512248931069*^9, 3.8115123200209227`*^9}, 
   3.811512625205599*^9, 3.8115730364841967`*^9, 3.8115738389469347`*^9},
 CellLabel->
  "Out[398]=",ExpressionUUID->"514f5826-796e-4311-9f39-53a3dfe45098"],

Cell[BoxData[
 FormBox[
  FractionBox["3", "4"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811501548343588*^9, 3.811502642065413*^9, {3.811502904975367*^9, 
   3.811502912268366*^9}, {3.811503028704659*^9, 3.811503077180458*^9}, {
   3.811503168775702*^9, 3.811503199863674*^9}, {3.811503281745028*^9, 
   3.811503297169136*^9}, 3.8115033606385527`*^9, 3.811503466870008*^9, 
   3.811503648879196*^9, {3.811503719092285*^9, 3.81150375058223*^9}, 
   3.8115042253879423`*^9, 3.811504277238379*^9, {3.811504394795763*^9, 
   3.811504407703858*^9}, 3.811504448742634*^9, {3.811505870025113*^9, 
   3.8115059194371758`*^9}, 3.811505973879974*^9, 3.811512057150193*^9, 
   3.811512106346786*^9, {3.811512248931069*^9, 3.8115123200209227`*^9}, 
   3.811512625205599*^9, 3.8115730364841967`*^9, 3.81157383903561*^9},
 CellLabel->
  "Out[399]=",ExpressionUUID->"c8858f9f-1051-4d09-9efb-ed0ba522ffca"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["mA", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["mA", "4"]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["mA", "2"], " ", "QSq"}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["QSq", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"]}]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["mA", "4"]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["mA", "2"], " ", "QSq"}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["QSq", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"]}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"2", " ", 
           SuperscriptBox["mA", "4"]}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["mA", "2"], " ", "QSq", " ", "\[Omega]"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["mA", "4"], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["mA", "2"], " ", "QSq"}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["QSq", "2"], " ", 
             SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
          RowBox[{"log", "(", 
           RowBox[{"QSq", " ", 
            RowBox[{"(", 
             RowBox[{"\[Omega]", "-", "1"}], ")"}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["mA", "4"], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["mA", "2"], " ", "QSq"}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["QSq", "2"], " ", 
             SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
          RowBox[{"log", "(", 
           RowBox[{
            RowBox[{"-", "QSq"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Omega]", "+", "1"}], ")"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["mA", "6"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["mA", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "QSq", " ", "\[Omega]"}], "+", "QSq"}], ")"}]}],
          "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["mA", "2"], " ", 
          SuperscriptBox["QSq", "2"], " ", "\[Omega]"}], "-", 
         RowBox[{"8", " ", 
          SuperscriptBox["QSq", "3"], " ", 
          SuperscriptBox["\[Omega]", "3"]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["tan", 
         RowBox[{"-", "1"}]], "(", 
        FractionBox[
         RowBox[{
          RowBox[{"2", " ", "QSq", " ", "\[Omega]"}], "-", 
          SuperscriptBox["mA", "2"]}], 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["mA", "4"]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["mA", "2"], " ", "QSq"}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["QSq", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"]}]}]]], ")"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["mA", "6"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["mA", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "QSq", " ", "\[Omega]"}], "+", "QSq"}], ")"}]}],
          "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["mA", "2"], " ", 
          SuperscriptBox["QSq", "2"], " ", "\[Omega]"}], "-", 
         RowBox[{"8", " ", 
          SuperscriptBox["QSq", "3"], " ", 
          SuperscriptBox["\[Omega]", "3"]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["tan", 
         RowBox[{"-", "1"}]], "(", 
        FractionBox[
         RowBox[{
          SuperscriptBox["mA", "2"], "+", 
          RowBox[{"2", " ", "QSq", " ", "\[Omega]"}]}], 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["mA", "4"]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["mA", "2"], " ", "QSq"}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["QSq", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"]}]}]]], ")"}]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811501548343588*^9, 3.811502642065413*^9, {3.811502904975367*^9, 
   3.811502912268366*^9}, {3.811503028704659*^9, 3.811503077180458*^9}, {
   3.811503168775702*^9, 3.811503199863674*^9}, {3.811503281745028*^9, 
   3.811503297169136*^9}, 3.8115033606385527`*^9, 3.811503466870008*^9, 
   3.811503648879196*^9, {3.811503719092285*^9, 3.81150375058223*^9}, 
   3.8115042253879423`*^9, 3.811504277238379*^9, {3.811504394795763*^9, 
   3.811504407703858*^9}, 3.811504448742634*^9, {3.811505870025113*^9, 
   3.8115059194371758`*^9}, 3.811505973879974*^9, 3.811512057150193*^9, 
   3.811512106346786*^9, {3.811512248931069*^9, 3.8115123200209227`*^9}, 
   3.811512625205599*^9, 3.8115730364841967`*^9, 3.811573839490176*^9},
 CellLabel->
  "Out[400]=",ExpressionUUID->"8b610696-df55-4e51-80e1-5c96e1031fdb"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"-", "\[Infinity]"}], 
   SuperscriptBox["mA", "4"]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811501548343588*^9, 3.811502642065413*^9, {3.811502904975367*^9, 
   3.811502912268366*^9}, {3.811503028704659*^9, 3.811503077180458*^9}, {
   3.811503168775702*^9, 3.811503199863674*^9}, {3.811503281745028*^9, 
   3.811503297169136*^9}, 3.8115033606385527`*^9, 3.811503466870008*^9, 
   3.811503648879196*^9, {3.811503719092285*^9, 3.81150375058223*^9}, 
   3.8115042253879423`*^9, 3.811504277238379*^9, {3.811504394795763*^9, 
   3.811504407703858*^9}, 3.811504448742634*^9, {3.811505870025113*^9, 
   3.8115059194371758`*^9}, 3.811505973879974*^9, 3.811512057150193*^9, 
   3.811512106346786*^9, {3.811512248931069*^9, 3.8115123200209227`*^9}, 
   3.811512625205599*^9, 3.8115730364841967`*^9, 3.81157384049181*^9},
 CellLabel->
  "Out[401]=",ExpressionUUID->"8e7b11da-460f-4d10-839c-ea2e87d3ae99"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Effective Decay Constant and SU(3)", "Section",
 CellChangeTimes->{{3.811576642018634*^9, 3.811576649668047*^9}, {
  3.8115767158948812`*^9, 
  3.811576717719632*^9}},ExpressionUUID->"97ee8c87-3ba6-45b7-a68c-\
2337d626738a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    SubscriptBox["f", "1"], " ", "and", " ", 
    SubsuperscriptBox["f", "1", "'"], " ", 
    RowBox[{"mixing", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Inverse", "[", 
    RowBox[{"(", GridBox[{
       {
        RowBox[{"Cos", "[", "\[Theta]", "]"}], 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]},
       {
        RowBox[{"-", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}
      }], ")"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.811574525719736*^9, 3.811574605721347*^9}, {
  3.811576615690041*^9, 
  3.8115766171957197`*^9}},ExpressionUUID->"6d7f1db9-546b-4f66-8eca-\
f0aa837a6042"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"cos", "(", "\[Theta]", ")"}], 
      RowBox[{"-", 
       RowBox[{"sin", "(", "\[Theta]", ")"}]}]},
     {
      RowBox[{"sin", "(", "\[Theta]", ")"}], 
      RowBox[{"cos", "(", "\[Theta]", ")"}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.811574603242435*^9, 3.811574605997414*^9}},
 CellLabel->
  "Out[404]=",ExpressionUUID->"cdf99bff-2681-4933-9c62-a1e19d7f6800"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "relative", " ", "magnitude", " ", "of", " ", 
    "\[CapitalGamma]", 
    RowBox[{
     RowBox[{"(", 
      SubscriptBox["f", "1"], ")"}], "/", "\[CapitalGamma]"}], 
    RowBox[{"(", 
     SubsuperscriptBox["f", "1", "'"], ")"}], " ", "in", " ", "view", " ", 
    "of", " ", "SU", 
    RowBox[{
     RowBox[{"(", "3", ")"}], "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"2", 
          SqrtBox["6"], 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
         RowBox[{
          SqrtBox["3"], 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], 
          SqrtBox["6"], 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
         RowBox[{
          SqrtBox["3"], 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]], ")"}], "2"], "//", 
     "TrigExpand"}], "//", "Simplify"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"Cot", "[", 
       RowBox[{"\[Theta]", "-", 
        RowBox[{"ArcSin", "[", 
         FractionBox["1", "3"], "]"}]}], "]"}], "2"], "//", "TrigExpand"}], "//",
     "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.811574827371895*^9, 3.811574867131709*^9}, {
  3.8115756029852552`*^9, 3.811575727118367*^9}, {3.811576580645226*^9, 
  3.811576625196602*^9}},
 CellLabel->
  "In[430]:=",ExpressionUUID->"b9c31de8-88cc-458e-9714-fa36524e49ff"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"4", " ", 
     SqrtBox["2"], " ", 
     RowBox[{"sin", "(", 
      RowBox[{"2", " ", "\[Theta]"}], ")"}]}], "+", 
    RowBox[{"7", " ", 
     RowBox[{"cos", "(", 
      RowBox[{"2", " ", "\[Theta]"}], ")"}]}], "+", "9"}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", "(", "\[Theta]", ")"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"], " ", 
        RowBox[{"sin", "(", "\[Theta]", ")"}]}]}], ")"}], "2"]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.811574862515951*^9, 3.811574867463654*^9}, {
   3.811575604025262*^9, 3.811575678013504*^9}, {3.8115757104832993`*^9, 
   3.811575727342122*^9}, 3.811576627542223*^9},
 CellLabel->
  "Out[430]=",ExpressionUUID->"f70600ce-45d9-4a2f-bd62-55adf716e005"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"4", " ", 
     SqrtBox["2"], " ", 
     RowBox[{"sin", "(", 
      RowBox[{"2", " ", "\[Theta]"}], ")"}]}], "+", 
    RowBox[{"7", " ", 
     RowBox[{"cos", "(", 
      RowBox[{"2", " ", "\[Theta]"}], ")"}]}], "+", "9"}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", "(", "\[Theta]", ")"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"], " ", 
        RowBox[{"sin", "(", "\[Theta]", ")"}]}]}], ")"}], "2"]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.811574862515951*^9, 3.811574867463654*^9}, {
   3.811575604025262*^9, 3.811575678013504*^9}, {3.8115757104832993`*^9, 
   3.811575727342122*^9}, 3.8115766276338797`*^9},
 CellLabel->
  "Out[431]=",ExpressionUUID->"d0ca4144-2089-4d4b-9d67-d46eea422687"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "relative", " ", "magnitude", " ", "of", " ", 
    "\[CapitalGamma]", 
    RowBox[{
     RowBox[{"(", 
      SubscriptBox["a", "1"], ")"}], "/", "\[CapitalGamma]"}], 
    RowBox[{"(", 
     SubscriptBox["f", "1"], ")"}], " ", "in", " ", "view", " ", "of", " ", 
    "SU", 
    RowBox[{
     RowBox[{"(", "3", ")"}], "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["3", 
        RowBox[{
         RowBox[{"2", 
          SqrtBox["6"], 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
         RowBox[{
          SqrtBox["3"], 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], ")"}], "2"], "//", 
     "TrigExpand"}], "//", "Simplify"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"3", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "-", 
          RowBox[{"ArcSin", "[", 
           FractionBox["1", "3"], "]"}]}], "]"}], "2"]}]], "//", 
     "TrigExpand"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.8115223984904413`*^9, 3.811522446912726*^9}, {
   3.811522519604867*^9, 3.8115225536221457`*^9}, {3.8115226291748953`*^9, 
   3.811522667329023*^9}, {3.811522755755804*^9, 3.811522838343841*^9}, {
   3.811523028860058*^9, 3.811523045453453*^9}, {3.8115231528234377`*^9, 
   3.811523152905862*^9}, {3.811573043430497*^9, 3.8115730488009977`*^9}, {
   3.811574500622555*^9, 3.8115745149730377`*^9}, 3.8115766389208717`*^9, {
   3.8115767335115128`*^9, 3.8115767673034687`*^9}, {3.811577328959552*^9, 
   3.811577404549782*^9}, 
   3.811583406288889*^9},ExpressionUUID->"9fa4579c-afe0-4a4c-ad04-\
992f6612aa6b"],

Cell[BoxData[
 FormBox[
  FractionBox["6", 
   RowBox[{
    RowBox[{"4", " ", 
     SqrtBox["2"], " ", 
     RowBox[{"sin", "(", 
      RowBox[{"2", " ", "\[Theta]"}], ")"}]}], "+", 
    RowBox[{"7", " ", 
     RowBox[{"cos", "(", 
      RowBox[{"2", " ", "\[Theta]"}], ")"}]}], "+", "9"}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.811522420322534*^9, 3.8115224471806927`*^9}, {
   3.811522530425624*^9, 3.8115225383546124`*^9}, {3.811522640198863*^9, 
   3.8115226675778027`*^9}, {3.8115227773108273`*^9, 3.8115228387811737`*^9}, 
   3.81152304833565*^9, 3.81152315325966*^9, {3.8115773723569527`*^9, 
   3.811577414944783*^9}},
 CellLabel->
  "Out[438]=",ExpressionUUID->"ea149e85-5c0c-4cf2-8f29-41b2dc8d4b4c"],

Cell[BoxData[
 FormBox[
  FractionBox["6", 
   RowBox[{
    RowBox[{"4", " ", 
     SqrtBox["2"], " ", 
     RowBox[{"sin", "(", 
      RowBox[{"2", " ", "\[Theta]"}], ")"}]}], "+", 
    RowBox[{"7", " ", 
     RowBox[{"cos", "(", 
      RowBox[{"2", " ", "\[Theta]"}], ")"}]}], "+", "9"}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.811522420322534*^9, 3.8115224471806927`*^9}, {
   3.811522530425624*^9, 3.8115225383546124`*^9}, {3.811522640198863*^9, 
   3.8115226675778027`*^9}, {3.8115227773108273`*^9, 3.8115228387811737`*^9}, 
   3.81152304833565*^9, 3.81152315325966*^9, {3.8115773723569527`*^9, 
   3.811577414950865*^9}},
 CellLabel->
  "Out[439]=",ExpressionUUID->"ea689e1a-f90e-4296-9c04-09d371288b47"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"NOT", " ", "REALLY", " ", 
    RowBox[{"NEEDED", "?", " ", "SOLVED"}], " ", "DIFFERENTLY", " ", "ON", 
    " ", 
    RowBox[{"SHEET", "?", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Gell", "-", 
    RowBox[{"Mann", " ", 
     RowBox[{"Matrices", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"List", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "\[ImaginaryI]"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[ImaginaryI]", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[ImaginaryI]", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "\[ImaginaryI]", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{
       FractionBox["1", 
        SqrtBox["3"]], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", 
           RowBox[{"-", "2"}]}], "}"}]}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"u", "-"}], ",", " ", 
     RowBox[{"d", "-"}], ",", " ", 
     RowBox[{
      RowBox[{"and", " ", "s"}], "-", 
      RowBox[{
      "quark", " ", "currents", " ", "in", " ", "terms", " ", "of", " ", 
       "cartesian", " ", 
       RowBox[{"basis", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             FractionBox["1", 
              SqrtBox["3"]], 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
            RowBox[{
             FractionBox["1", 
              SqrtBox["6"]], 
             RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", "0", ",", "0"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"2", "/", "3"}]], "a0", "*", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "+", 
        RowBox[{"a1", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "+", 
        RowBox[{"a2", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "+", 
        RowBox[{"a3", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "+", 
        RowBox[{"a4", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "+", 
        RowBox[{"a5", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "5", "]"}], "]"}]}], "+", 
        RowBox[{"a6", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "6", "]"}], "]"}]}], "+", 
        RowBox[{"a7", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "7", "]"}], "]"}]}], "+", 
        RowBox[{"a8", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "8", "]"}], "]"}]}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{
       "a0", ",", "a1", ",", "a2", ",", "a3", ",", "a4", ",", "a5", ",", "a6",
         ",", "a7", ",", "a8"}], "}"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              SqrtBox["3"]], 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
            RowBox[{
             FractionBox["1", 
              SqrtBox["6"]], 
             RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", "0"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"2", "/", "3"}]], "a0", "*", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "+", 
        RowBox[{"a1", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "+", 
        RowBox[{"a2", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "+", 
        RowBox[{"a3", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "+", 
        RowBox[{"a4", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "+", 
        RowBox[{"a5", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "5", "]"}], "]"}]}], "+", 
        RowBox[{"a6", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "6", "]"}], "]"}]}], "+", 
        RowBox[{"a7", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "7", "]"}], "]"}]}], "+", 
        RowBox[{"a8", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "8", "]"}], "]"}]}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{
       "a0", ",", "a1", ",", "a2", ",", "a3", ",", "a4", ",", "a5", ",", "a6",
         ",", "a7", ",", "a8"}], "}"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             FractionBox["1", 
              SqrtBox["3"]], 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
            RowBox[{
             FractionBox["1", 
              SqrtBox["6"]], 
             RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", "0", ",", "0"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              SqrtBox["3"]], 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
            RowBox[{
             FractionBox["1", 
              SqrtBox["6"]], 
             RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", "0"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"2", "/", "3"}]], "a0", "*", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "+", 
        RowBox[{"a1", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "+", 
        RowBox[{"a2", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "+", 
        RowBox[{"a3", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "+", 
        RowBox[{"a4", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "+", 
        RowBox[{"a5", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "5", "]"}], "]"}]}], "+", 
        RowBox[{"a6", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "6", "]"}], "]"}]}], "+", 
        RowBox[{"a7", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "7", "]"}], "]"}]}], "+", 
        RowBox[{"a8", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "8", "]"}], "]"}]}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{
       "a0", ",", "a1", ",", "a2", ",", "a3", ",", "a4", ",", "a5", ",", "a6",
         ",", "a7", ",", "a8"}], "}"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", 
           RowBox[{
            RowBox[{
             FractionBox["1", 
              SqrtBox["3"]], 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
            RowBox[{
             FractionBox["2", 
              SqrtBox["6"]], 
             RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}]}], "}"}], 
       "\[Equal]", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"2", "/", "3"}]], "a0", "*", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "+", 
        RowBox[{"a1", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "+", 
        RowBox[{"a2", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "+", 
        RowBox[{"a3", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "+", 
        RowBox[{"a4", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "+", 
        RowBox[{"a5", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "5", "]"}], "]"}]}], "+", 
        RowBox[{"a6", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "6", "]"}], "]"}]}], "+", 
        RowBox[{"a7", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "7", "]"}], "]"}]}], "+", 
        RowBox[{"a8", "*", 
         RowBox[{"\[Lambda]", "[", 
          RowBox[{"[", "8", "]"}], "]"}]}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{
       "a0", ",", "a1", ",", "a2", ",", "a3", ",", "a4", ",", "a5", ",", "a6",
         ",", "a7", ",", "a8"}], "}"}]}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.801328348272809*^9, 3.801328531647002*^9}, {
  3.81158347782028*^9, 3.811583517672064*^9}, {3.8115842021180773`*^9, 
  3.811584204298275*^9}, {3.811654021064947*^9, 3.81165408930967*^9}, {
  3.811654558043148*^9, 3.811654577554042*^9}, {3.8116570046704683`*^9, 
  3.811657019228997*^9}},ExpressionUUID->"6b3c11d5-1a9b-49c1-88c8-\
75c1d15ac958"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"-", "\[ImaginaryI]"}], ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\[ImaginaryI]", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}], ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "0"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"\[ImaginaryI]", ",", "0", ",", "0"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "0"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", "\[ImaginaryI]", ",", "0"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        FractionBox["1", 
         SqrtBox["3"]], ",", "0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        FractionBox["1", 
         SqrtBox["3"]], ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", 
         FractionBox["2", 
          SqrtBox["3"]]}]}], "}"}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8115825144039288`*^9, 3.811583518245261*^9, 3.8115842047486353`*^9, 
   3.811654040214773*^9, 3.811654091983613*^9, {3.81165456121879*^9, 
   3.811654578509447*^9}},
 CellLabel->
  "Out[486]=",ExpressionUUID->"5fbb49a7-4ca8-4500-94cd-f10a5bcab5d6"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a0", "\[Rule]", 
      RowBox[{
       FractionBox["1", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"sin", "(", "\[Theta]", ")"}], "+", 
         RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"cos", "(", "\[Theta]", ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{"a1", "\[Rule]", "0"}], ",", 
     RowBox[{"a2", "\[Rule]", "0"}], ",", 
     RowBox[{"a3", "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{
         SqrtBox["2"], " ", 
         RowBox[{"sin", "(", "\[Theta]", ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"cos", "(", "\[Theta]", ")"}]}]}], 
       RowBox[{"4", " ", 
        SqrtBox["3"]}]]}], ",", 
     RowBox[{"a4", "\[Rule]", "0"}], ",", 
     RowBox[{"a5", "\[Rule]", "0"}], ",", 
     RowBox[{"a6", "\[Rule]", "0"}], ",", 
     RowBox[{"a7", "\[Rule]", "0"}], ",", 
     RowBox[{"a8", "\[Rule]", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"sin", "(", "\[Theta]", ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"cos", "(", "\[Theta]", ")"}]}]}], ")"}]}]}]}], "}"}], 
   "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8115825144039288`*^9, 3.811583518245261*^9, 3.8115842047486353`*^9, 
   3.811654040214773*^9, 3.811654091983613*^9, {3.81165456121879*^9, 
   3.8116545785197163`*^9}},
 CellLabel->
  "Out[487]=",ExpressionUUID->"7c5a3dd3-7f14-48c9-9d0e-2ff72c8b1565"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a0", "\[Rule]", 
      RowBox[{
       FractionBox["1", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"sin", "(", "\[Theta]", ")"}], "+", 
         RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"cos", "(", "\[Theta]", ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{"a1", "\[Rule]", "0"}], ",", 
     RowBox[{"a2", "\[Rule]", "0"}], ",", 
     RowBox[{"a3", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"sin", "(", "\[Theta]", ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"cos", "(", "\[Theta]", ")"}]}]}], 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]]}]}], ",", 
     RowBox[{"a4", "\[Rule]", "0"}], ",", 
     RowBox[{"a5", "\[Rule]", "0"}], ",", 
     RowBox[{"a6", "\[Rule]", "0"}], ",", 
     RowBox[{"a7", "\[Rule]", "0"}], ",", 
     RowBox[{"a8", "\[Rule]", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"sin", "(", "\[Theta]", ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"cos", "(", "\[Theta]", ")"}]}]}], ")"}]}]}]}], "}"}], 
   "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8115825144039288`*^9, 3.811583518245261*^9, 3.8115842047486353`*^9, 
   3.811654040214773*^9, 3.811654091983613*^9, {3.81165456121879*^9, 
   3.81165457856933*^9}},
 CellLabel->
  "Out[488]=",ExpressionUUID->"f786cca1-2d73-412e-8254-ade6a1d9d2d1"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a0", "\[Rule]", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"sin", "(", "\[Theta]", ")"}], "+", 
         RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"cos", "(", "\[Theta]", ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{"a1", "\[Rule]", "0"}], ",", 
     RowBox[{"a2", "\[Rule]", "0"}], ",", 
     RowBox[{"a3", "\[Rule]", "0"}], ",", 
     RowBox[{"a4", "\[Rule]", "0"}], ",", 
     RowBox[{"a5", "\[Rule]", "0"}], ",", 
     RowBox[{"a6", "\[Rule]", "0"}], ",", 
     RowBox[{"a7", "\[Rule]", "0"}], ",", 
     RowBox[{"a8", "\[Rule]", 
      RowBox[{
       FractionBox["1", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"sin", "(", "\[Theta]", ")"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"cos", "(", "\[Theta]", ")"}]}]}], ")"}]}]}]}], "}"}], 
   "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8115825144039288`*^9, 3.811583518245261*^9, 3.8115842047486353`*^9, 
   3.811654040214773*^9, 3.811654091983613*^9, {3.81165456121879*^9, 
   3.81165457857586*^9}},
 CellLabel->
  "Out[489]=",ExpressionUUID->"e83233bd-e4d2-4ce5-b5c4-d7112b69476c"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a0", "\[Rule]", 
      RowBox[{
       FractionBox["1", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"cos", "(", "\[Theta]", ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"sin", "(", "\[Theta]", ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{"a1", "\[Rule]", "0"}], ",", 
     RowBox[{"a2", "\[Rule]", "0"}], ",", 
     RowBox[{"a3", "\[Rule]", "0"}], ",", 
     RowBox[{"a4", "\[Rule]", "0"}], ",", 
     RowBox[{"a5", "\[Rule]", "0"}], ",", 
     RowBox[{"a6", "\[Rule]", "0"}], ",", 
     RowBox[{"a7", "\[Rule]", "0"}], ",", 
     RowBox[{"a8", "\[Rule]", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"sin", "(", "\[Theta]", ")"}]}], "-", 
         RowBox[{"cos", "(", "\[Theta]", ")"}]}], ")"}]}]}]}], "}"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8115825144039288`*^9, 3.811583518245261*^9, 3.8115842047486353`*^9, 
   3.811654040214773*^9, 3.811654091983613*^9, {3.81165456121879*^9, 
   3.8116545785806932`*^9}},
 CellLabel->
  "Out[490]=",ExpressionUUID->"26c1f6d6-3ba9-42d0-b3e4-6bf54f27b2fd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"NOT", " ", "REALLY", " ", 
    RowBox[{"NEEDED", "?", " ", "NO"}], " ", "IDEA", " ", "HOW", " ", "TO", 
    " ", "GET", " ", "TO", " ", "THE", " ", "EFFECTIVE", " ", "DECAY", " ", 
    RowBox[{"CONSTANTS", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"2", "F0", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["2", "3"], ")"}], 
         RowBox[{"3", "/", "2"}]], 
        FractionBox["mA0", "mf1"], 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"2", "F8"}], 
         RowBox[{"3", 
          SqrtBox["3"]}]], 
        FractionBox["mA8", "mf1"], 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"X", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"F0", "*", 
           SqrtBox[
            FractionBox["2", "3"]], 
           FractionBox["mA0", "mf1"], 
           RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
          RowBox[{
           FractionBox["F8", 
            SqrtBox["3"]], "*", 
           FractionBox["mA8", "mf1"], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"Y", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"F0", "*", 
           SqrtBox[
            FractionBox["2", "3"]], 
           FractionBox["mA0", "mf1"], 
           RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
          RowBox[{
           FractionBox["F8", 
            SqrtBox["3"]], "*", 
           FractionBox["mA8", "mf1"], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"Z", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"F0", "*", 
           SqrtBox[
            FractionBox["2", "3"]], 
           FractionBox["mA0", "mf1"], 
           RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
          RowBox[{
           FractionBox[
            RowBox[{"2", "F8"}], 
            SqrtBox["3"]], "*", 
           FractionBox["mA8", "mf1"], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], "F0", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["2", "3"], ")"}], 
         RowBox[{"3", "/", "2"}]], 
        FractionBox["mA0", "mf1P"], 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"2", "F8"}], 
         RowBox[{"3", 
          SqrtBox["3"]}]], 
        FractionBox["mA8", "mf1P"], 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"X", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "F0"}], "*", 
           SqrtBox[
            FractionBox["2", "3"]], 
           FractionBox["mA0", "mf1P"], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
          RowBox[{
           FractionBox["F8", 
            SqrtBox["3"]], "*", 
           FractionBox["mA8", "mf1P"], 
           RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"Y", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "F0"}], "*", 
           SqrtBox[
            FractionBox["2", "3"]], 
           FractionBox["mA0", "mf1P"], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
          RowBox[{
           FractionBox["F8", 
            SqrtBox["3"]], "*", 
           FractionBox["mA8", "mf1P"], 
           RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"Z", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "F0"}], "*", 
           SqrtBox[
            FractionBox["2", "3"]], 
           FractionBox["mA0", "mf1P"], 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
          RowBox[{
           FractionBox[
            RowBox[{"2", "F8"}], 
            SqrtBox["3"]], "*", 
           FractionBox["mA8", "mf1P"], 
           RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}]}]}]}], "&&", 
     RowBox[{"X", "\[Equal]", 
      RowBox[{"Y", "+", "1"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"X", ",", "Y", ",", "Z"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.811660189471266*^9, 3.811660403966302*^9}, {
  3.811660446925354*^9, 3.811660449644601*^9}, {3.811660484443782*^9, 
  3.811660535692752*^9}, {3.811660590389064*^9, 3.811660607440621*^9}, {
  3.811660771878731*^9, 3.811660773513522*^9}, {3.8116656301697483`*^9, 
  3.811665661243335*^9}, {3.811665834509018*^9, 3.811665836682167*^9}, {
  3.8116684716005917`*^9, 
  3.811668486912963*^9}},ExpressionUUID->"00eac9e0-ad47-4f5c-b42b-\
257193a72965"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"X", "\[Rule]", 
      FractionBox["19", "18"]}], ",", 
     RowBox[{"Y", "\[Rule]", 
      FractionBox["1", "18"]}], ",", 
     RowBox[{"Z", "\[Rule]", 
      FractionBox["2", "9"]}]}], "}"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811660536425294*^9, 3.811660607822536*^9, 3.811660774008746*^9, {
   3.811665637338442*^9, 3.811665661675734*^9}, 3.8116658371107073`*^9},
 CellLabel->
  "Out[514]=",ExpressionUUID->"b2f75389-6e48-4a8e-9a35-46e5707d151a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Get", " ", "the", " ", "normalizations", " ", 
     SubscriptBox["F", "2"], 
     RowBox[{"(", 
      RowBox[{"0", ",", "0"}], ")"}], " ", "from", " ", "the", " ", "two"}], 
    "-", 
    RowBox[{"photon", " ", "decay", " ", "width", " ", "for", " ", "the", " ", 
     SubscriptBox["f", "1"], " ", "and", " ", 
     RowBox[{
      SubsuperscriptBox["f", "1", "'"], "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SqrtBox[
      FractionBox[
       RowBox[{"12", "\[CapitalGamma]"}], 
       RowBox[{
        RowBox[{"\[Pi]", "/", 
         SuperscriptBox["137", "2"]}], "mA"}]]], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mA", "\[Rule]", "1281.9"}], ",", 
       RowBox[{"\[CapitalGamma]", "\[Rule]", 
        RowBox[{"3.5", "*", 
         SuperscriptBox["10", 
          RowBox[{"-", "3"}]]}]}]}], "}"}]}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      FractionBox[
       RowBox[{"12", "\[CapitalGamma]"}], 
       RowBox[{
        RowBox[{"\[Pi]", "/", 
         SuperscriptBox["137", "2"]}], "mA"}]]], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mA", "\[Rule]", "1426.4"}], ",", 
       RowBox[{"\[CapitalGamma]", "\[Rule]", 
        RowBox[{"3.2", "*", 
         SuperscriptBox["10", 
          RowBox[{"-", "3"}]]}]}]}], "}"}]}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"F200", " ", "mA"}], "2"], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mA", "\[Rule]", "1281.9"}], ",", 
       RowBox[{"F200", "\[Rule]", "0.442429"}]}], "}"}]}], "//", "Simplify"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"F200", " ", "mA"}], "2"], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mA", "\[Rule]", "1426.4"}], ",", 
       RowBox[{"F200", "\[Rule]", "0.401043"}]}], "}"}]}], "//", "Simplify"}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"F200", " ", 
       SuperscriptBox["\[CapitalLambda]", "4"]}], 
      RowBox[{"3", 
       SuperscriptBox["mA", "3"]}]], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"F200", "\[Rule]", "0.442429"}], ",", 
       RowBox[{"mA", "\[Rule]", "1281.9"}], ",", 
       RowBox[{"\[CapitalLambda]", "\[Rule]", "1040"}]}], "}"}]}], "//", 
    "Simplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"F200", " ", 
       SuperscriptBox["\[CapitalLambda]", "4"]}], 
      RowBox[{"3", 
       SuperscriptBox["mA", "3"]}]], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"F200", "\[Rule]", "0.401043"}], ",", 
       RowBox[{"mA", "\[Rule]", "1426.4"}], ",", 
       RowBox[{"\[CapitalLambda]", "\[Rule]", "926"}]}], "}"}]}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.811668492142159*^9, 3.8116686152505302`*^9}, {
  3.811668709619501*^9, 3.811668733725235*^9}, {3.811668823926633*^9, 
  3.8116689072005253`*^9}},
 CellLabel->
  "In[530]:=",ExpressionUUID->"9c7b4b83-f391-4a3e-a5fe-fa6cde19d452"],

Cell[BoxData[
 FormBox["0.4424286090169698`", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811668543859024*^9, 3.811668582933217*^9, {3.811668715253484*^9, 
   3.8116687340887337`*^9}, 3.811668867334441*^9, 3.811668907732428*^9},
 CellLabel->
  "Out[530]=",ExpressionUUID->"01f9c5e6-1133-45b3-8098-073d08297158"],

Cell[BoxData[
 FormBox["0.4010426653053051`", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811668543859024*^9, 3.811668582933217*^9, {3.811668715253484*^9, 
   3.8116687340887337`*^9}, 3.811668867334441*^9, 3.81166890774303*^9},
 CellLabel->
  "Out[531]=",ExpressionUUID->"22de54e8-0187-41b0-b8d8-de79e56d830d"],

Cell[BoxData[
 FormBox["283.57486755`", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811668543859024*^9, 3.811668582933217*^9, {3.811668715253484*^9, 
   3.8116687340887337`*^9}, 3.811668867334441*^9, 3.8116689077475777`*^9},
 CellLabel->
  "Out[532]=",ExpressionUUID->"485443e3-6999-46e1-8a7b-29f72652e7a8"],

Cell[BoxData[
 FormBox["286.0238676`", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811668543859024*^9, 3.811668582933217*^9, {3.811668715253484*^9, 
   3.8116687340887337`*^9}, 3.811668867334441*^9, 3.8116689077522*^9},
 CellLabel->
  "Out[533]=",ExpressionUUID->"8aef83d0-a9ad-4ca7-a3fa-587267af96dc"],

Cell[BoxData[
 FormBox["81.9017621527331`", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811668543859024*^9, 3.811668582933217*^9, {3.811668715253484*^9, 
   3.8116687340887337`*^9}, 3.811668867334441*^9, 3.8116689077572412`*^9},
 CellLabel->
  "Out[534]=",ExpressionUUID->"c6c8f512-646d-463e-933f-3c6502059b69"],

Cell[BoxData[
 FormBox["33.86800707792115`", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.811668543859024*^9, 3.811668582933217*^9, {3.811668715253484*^9, 
   3.8116687340887337`*^9}, 3.811668867334441*^9, 3.811668907761408*^9},
 CellLabel->
  "Out[535]=",ExpressionUUID->"7f586946-aa34-49a6-a278-e532df0ae3c7"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 716},
WindowMargins->{{-51, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 170, 3, 97, "Title",ExpressionUUID->"71d6ba4a-c817-4eff-af2f-87e0d0bd0fa8"],
Cell[753, 27, 379, 8, 57, "Text",ExpressionUUID->"8ee7c4eb-e3f7-47b1-8806-b5a09d2617d2"],
Cell[CellGroupData[{
Cell[1157, 39, 257, 4, 69, "Section",ExpressionUUID->"f5fb4b36-0a04-4d2f-a83e-aeb9aaedd440"],
Cell[CellGroupData[{
Cell[1439, 47, 1800, 49, 148, "Input",ExpressionUUID->"9dc681e4-2297-49fc-84c8-ebfc4cb422b0"],
Cell[3242, 98, 295, 7, 60, "Output",ExpressionUUID->"dd745792-2fd3-4776-97de-884ba5355449"],
Cell[3540, 107, 270, 6, 60, "Output",ExpressionUUID->"02c464e8-b819-4d42-b320-2fdfd22f360e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3859, 119, 185, 3, 69, "Chapter",ExpressionUUID->"5b7cd0ac-7c94-410b-9ae6-6f00f12ab45c"],
Cell[CellGroupData[{
Cell[4069, 126, 328, 7, 63, "Input",ExpressionUUID->"420a0d6f-e81f-4b30-aba9-919cc4401a3d"],
Cell[CellGroupData[{
Cell[4422, 137, 2480, 68, 30, "Print",ExpressionUUID->"d9aca1fe-9c08-4648-857f-bc52b18b8419"],
Cell[6905, 207, 1263, 34, 30, "Print",ExpressionUUID->"9d3176cb-bc6f-4629-827a-e9ffa29a17c1"],
Cell[8171, 243, 421, 9, 27, "Print",ExpressionUUID->"4d45619a-b40e-4db4-aa78-8acf805bfeb3"],
Cell[8595, 254, 406, 9, 27, "Print",ExpressionUUID->"bfecb07f-5c66-4125-8de2-9cc1722a46f3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9050, 269, 280, 5, 69, "Section",ExpressionUUID->"fa45b845-8c52-4d7a-8606-fce482ac74c3"],
Cell[CellGroupData[{
Cell[9355, 278, 2197, 59, 148, "Input",ExpressionUUID->"54ca3f32-a947-4a10-a6fc-1283bce4327b"],
Cell[11555, 339, 514, 11, 57, "Output",ExpressionUUID->"db45e79c-8c12-4408-9574-e176dc7a43f1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12106, 355, 2216, 56, 219, "Input",ExpressionUUID->"9ecce627-cd03-468d-9c31-593293b77d4f"],
Cell[14325, 413, 566, 13, 66, "Output",ExpressionUUID->"c9056001-7db6-49c7-b8c2-44bef6e8db1d"],
Cell[14894, 428, 566, 12, 57, "Output",ExpressionUUID->"5ff7764d-b1b4-4fcf-bf65-2c2f126f1e7b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15509, 446, 284, 4, 69, "Section",ExpressionUUID->"0aa6a4a7-35ee-4068-bcbb-9bc6f6659ffb"],
Cell[CellGroupData[{
Cell[15818, 454, 4295, 119, 250, "Input",ExpressionUUID->"4401c0a9-9946-495c-8f00-da9d14fe7e21"],
Cell[20116, 575, 4003, 129, 70, "Output",ExpressionUUID->"5420aeb1-2dae-4fa9-be8a-84c111df3f6b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24156, 709, 2868, 73, 239, "Input",ExpressionUUID->"a55ddf20-19ea-4902-80c5-f9c2dfc293f2"],
Cell[27027, 784, 3942, 117, 94, "Output",ExpressionUUID->"49008e43-f7a1-4c0c-af4b-68b68868d94c"],
Cell[30972, 903, 953, 19, 66, "Output",ExpressionUUID->"9fb897fe-c8d8-43cf-973c-0a5066017a6a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[31974, 928, 335, 5, 69, "Section",ExpressionUUID->"3788d55f-d502-4d0e-9bdd-b16ce117b6bd"],
Cell[32312, 935, 251, 7, 41, "Input",ExpressionUUID->"fd20cadb-d92b-4bbf-9fa1-7334c3c21ba5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32600, 947, 386, 6, 69, "Section",ExpressionUUID->"4d075ae9-1b13-4c1e-b042-97dc202fe2d3"],
Cell[CellGroupData[{
Cell[33011, 957, 12290, 364, 705, "Input",ExpressionUUID->"922f3ee2-a9ab-43d9-b6c2-e3086c99f2b2"],
Cell[45304, 1323, 1111, 25, 57, "Output",ExpressionUUID->"80cba7f2-f7ed-40af-8c0e-d9d426e7d009"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46452, 1353, 2370, 55, 201, "Input",ExpressionUUID->"c70fdad8-0206-4368-b37e-5a3adcf00a35"],
Cell[48825, 1410, 1533, 39, 81, "Output",ExpressionUUID->"6b11fede-349c-4e2d-a058-c78c9618251f"],
Cell[50361, 1451, 1539, 39, 80, "Output",ExpressionUUID->"b8c54b8a-d859-4f57-a823-8d67c599fe95"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[51961, 1497, 244, 4, 69, "Chapter",ExpressionUUID->"a94ef0ac-6d7e-4a26-bd31-eb2e49f91def"],
Cell[52208, 1503, 811, 23, 84, "Input",ExpressionUUID->"10164ac5-8161-4676-b9d0-41d3983c3518"],
Cell[CellGroupData[{
Cell[53044, 1530, 164, 3, 69, "Section",ExpressionUUID->"9aee6d91-0830-4e98-8d07-0d22b3cb6ba0"],
Cell[CellGroupData[{
Cell[53233, 1537, 5395, 157, 543, "Input",ExpressionUUID->"539a2ec1-7871-407f-a49f-44a1e6e95370"],
Cell[58631, 1696, 842, 18, 84, "Output",ExpressionUUID->"2e485cb6-e073-460e-b70e-f921c6f7acbe"],
Cell[59476, 1716, 574, 9, 37, "Output",ExpressionUUID->"01c2f65e-b389-4f74-8383-0cc5bfc90e74"],
Cell[60053, 1727, 597, 10, 57, "Output",ExpressionUUID->"ce00cc6d-ae59-42cb-bf79-c933321194c3"],
Cell[60653, 1739, 1160, 28, 93, "Output",ExpressionUUID->"a05569bf-5a94-477f-a146-e41ec4563573"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[61862, 1773, 209, 4, 69, "Section",ExpressionUUID->"a7cc3757-aa9b-4788-b49e-abf935bafd74"],
Cell[CellGroupData[{
Cell[62096, 1781, 2009, 41, 142, "Input",ExpressionUUID->"f458425e-9f45-4159-9055-6d32929dbd14"],
Cell[64108, 1824, 930, 21, 75, "Output",ExpressionUUID->"2e8dfa26-637b-49b2-afde-fcb2da737e73"],
Cell[65041, 1847, 1134, 27, 93, "Output",ExpressionUUID->"3d7edef8-005e-4aa1-9f8c-70d9e882b6e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66212, 1879, 260, 6, 63, "Input",ExpressionUUID->"b8609643-1009-48cd-8d4d-c5747cdd975f"],
Cell[CellGroupData[{
Cell[66497, 1889, 2478, 68, 30, "Print",ExpressionUUID->"127078e6-93a8-43b9-b699-603633230251"],
Cell[68978, 1959, 1263, 34, 30, "Print",ExpressionUUID->"30aa5a29-2451-494e-ba11-28fa3eaf9d0e"],
Cell[70244, 1995, 419, 9, 27, "Print",ExpressionUUID->"a4b1f289-4482-4a29-9b72-301cc13525aa"],
Cell[70666, 2006, 406, 9, 27, "Print",ExpressionUUID->"70e9eeaf-aed7-4bd5-8976-945b15a2858a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[71121, 2021, 4194, 112, 230, "Input",ExpressionUUID->"6ea33835-d082-44ad-af7b-093efe6636db"],
Cell[75318, 2135, 352, 5, 37, "Output",ExpressionUUID->"4af6e81c-3a7e-4a5f-8cf3-3aefeccad1a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75707, 2145, 5675, 164, 231, "Input",ExpressionUUID->"c1c1862f-aacf-4591-8e87-d4c009c064b8"],
Cell[81385, 2311, 935, 29, 64, "Output",ExpressionUUID->"b9a82dc4-fbd5-4f2e-853c-010810ecf4d6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82357, 2345, 2722, 79, 224, "Input",ExpressionUUID->"05922445-603e-48ce-a6c5-12da3fd0cc57"],
Cell[85082, 2426, 401, 8, 37, "Output",ExpressionUUID->"eea75eee-9069-4d5a-b346-9ba799575cc8"],
Cell[85486, 2436, 799, 23, 68, "Output",ExpressionUUID->"0b866110-914b-4608-92e9-3ef909c8e3c3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[86334, 2465, 261, 4, 69, "Section",ExpressionUUID->"676e1e12-28e9-4a02-b33e-15142f218c57"],
Cell[CellGroupData[{
Cell[86620, 2473, 2546, 65, 185, "Input",ExpressionUUID->"3d96dd02-8c6f-4f48-ac5f-ac5e0bc12f82"],
Cell[89169, 2540, 7874, 148, 246, "Output",ExpressionUUID->"fe21293f-fdb9-4d4e-a315-fd8c5af787aa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97080, 2693, 1205, 33, 79, "Input",ExpressionUUID->"dc3b9fa3-98b7-4b4e-91ee-cb12790bc0de"],
Cell[98288, 2728, 632, 12, 37, "Output",ExpressionUUID->"50ea0517-d582-4e8d-812d-27c9a492435a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98957, 2745, 1030, 30, 101, "Input",ExpressionUUID->"7d9da512-8aa7-4745-8077-789f7e691a61"],
Cell[99990, 2777, 756, 17, 57, "Output",ExpressionUUID->"40811c6f-88a0-47dd-9ae6-dafe41a96e30"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100783, 2799, 9541, 242, 463, "Input",ExpressionUUID->"2adc9422-daf3-40ee-bf47-c6a9376dabf6"],
Cell[110327, 3043, 1164, 36, 65, "Output",ExpressionUUID->"e19f262c-21a7-4d42-911a-146bc3a51934"],
Cell[111494, 3081, 199, 3, 37, "Output",ExpressionUUID->"ec0146f7-cd2f-4280-96ca-f74775d4852f"],
Cell[111696, 3086, 736, 23, 66, "Output",ExpressionUUID->"5a6f1194-ca0d-4609-8f53-d6a6b6a1d4a8"],
Cell[112435, 3111, 431, 13, 62, "Output",ExpressionUUID->"35e7ad14-acaa-4944-8f76-0695f0022412"],
Cell[112869, 3126, 199, 3, 37, "Output",ExpressionUUID->"49aac906-76a1-42c3-9be3-dd8a3f3fde08"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113105, 3134, 261, 6, 63, "Input",ExpressionUUID->"2256c081-19c2-4bec-b5f2-6a56dbf09c26"],
Cell[CellGroupData[{
Cell[113391, 3144, 2429, 67, 30, "Print",ExpressionUUID->"1c62b468-a821-4c52-a34d-48da9d739e6d"],
Cell[115823, 3213, 1213, 33, 30, "Print",ExpressionUUID->"cec6a4fa-87fc-4728-b2bf-94a2af5e698e"],
Cell[117039, 3248, 370, 8, 27, "Print",ExpressionUUID->"dc27f9ac-3425-4358-b847-313865cce8f8"],
Cell[117412, 3258, 355, 8, 27, "Print",ExpressionUUID->"311e510d-5fa1-480b-9937-bb24154a0ad5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[117816, 3272, 26533, 686, 996, "Input",ExpressionUUID->"95349e27-62b9-45f6-8c61-3f72e70c653e"],
Cell[144352, 3960, 436, 11, 24, "Message",ExpressionUUID->"76134b38-0fbf-4766-bfd5-dfa05b2f1f33"],
Cell[144791, 3973, 4012, 124, 68, "Output",ExpressionUUID->"a7f79af2-c7a4-4e3e-bc79-08a1f250c3a1"]
}, Open  ]],
Cell[148818, 4100, 15338, 393, 1094, "Input",ExpressionUUID->"44387abb-7efb-4ccf-9acb-17c540943442"],
Cell[164159, 4495, 2080, 62, 156, "Input",ExpressionUUID->"4bea8122-0fbc-48a2-8cad-cd3a6f4ed677"],
Cell[CellGroupData[{
Cell[166264, 4561, 2443, 74, 168, "Input",ExpressionUUID->"07423eda-400f-44ab-bd20-780c9f07b41d"],
Cell[168710, 4637, 1271, 39, 69, "Output",ExpressionUUID->"e09c7bdd-1dba-40ca-a1f0-b281c9cf0c8d"],
Cell[169984, 4678, 584, 17, 73, "Output",ExpressionUUID->"87e86c3a-2854-46fd-ab5c-2537178794c0"],
Cell[170571, 4697, 582, 17, 73, "Output",ExpressionUUID->"ee1aa2aa-d93c-40ef-baa7-1428854a30e4"],
Cell[171156, 4716, 892, 28, 69, "Output",ExpressionUUID->"1aa7ad75-feb4-4c17-a6c3-bd2e1b26ac09"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172085, 4749, 1520, 40, 89, "Input",ExpressionUUID->"9424bee5-cc65-46cf-a622-40210ef4b269"],
Cell[173608, 4791, 1670, 52, 69, "Output",ExpressionUUID->"bfacced3-364e-4995-8b27-611a2bb66f2d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[175327, 4849, 268, 4, 69, "Section",ExpressionUUID->"85dd1ba1-a9ba-49dd-a4ba-c54872449eca"],
Cell[CellGroupData[{
Cell[175620, 4857, 2865, 81, 183, "Input",ExpressionUUID->"00acf006-8fd7-4b05-aa42-bfbc23c12a09"],
Cell[178488, 4940, 1228, 32, 66, "Output",ExpressionUUID->"a1196eb5-d2f6-4f67-af0b-79a0b111de50"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179753, 4977, 3165, 101, 221, "Input",ExpressionUUID->"e327252a-2773-4c6f-83b5-efd8bf89a9f6"],
Cell[182921, 5080, 1063, 32, 66, "Output",ExpressionUUID->"93baa218-bfb9-4886-804b-74295f2e2d28"],
Cell[183987, 5114, 1089, 33, 66, "Output",ExpressionUUID->"4ca9e11a-4896-49a4-bb26-a4a83f959abb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185113, 5152, 5000, 150, 338, "Input",ExpressionUUID->"5b431a67-9a79-417e-8564-7c915ac229d2"],
Cell[190116, 5304, 1180, 35, 66, "Output",ExpressionUUID->"52131f1a-524a-4a52-a19e-f3baaa051593"],
Cell[191299, 5341, 1256, 37, 66, "Output",ExpressionUUID->"6b39b050-8ed1-45cb-b023-28054a05a4e7"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[192616, 5385, 236, 4, 69, "Chapter",ExpressionUUID->"5c18aeeb-b910-4ef7-a7d3-407d0b0f4e68"],
Cell[CellGroupData[{
Cell[192877, 5393, 162, 3, 69, "Section",ExpressionUUID->"49ea13c1-3006-4f86-a574-9c8a3d1d754c"],
Cell[CellGroupData[{
Cell[193064, 5400, 9528, 257, 633, "Input",ExpressionUUID->"4eafd805-f5b6-4de2-a10b-5dc52c1ba3c6"],
Cell[202595, 5659, 904, 15, 57, "Output",ExpressionUUID->"9ee07238-4b1f-4e3d-bf2b-ce5a62601f5a"],
Cell[203502, 5676, 1251, 27, 57, "Output",ExpressionUUID->"514f5826-796e-4311-9f39-53a3dfe45098"],
Cell[204756, 5705, 903, 15, 57, "Output",ExpressionUUID->"c8858f9f-1051-4d09-9efb-ed0ba522ffca"],
Cell[205662, 5722, 5299, 141, 235, "Output",ExpressionUUID->"8b610696-df55-4e51-80e1-5c96e1031fdb"],
Cell[210964, 5865, 958, 17, 55, "Output",ExpressionUUID->"8e7b11da-460f-4d10-839c-ea2e87d3ae99"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[211971, 5888, 230, 4, 69, "Section",ExpressionUUID->"97ee8c87-3ba6-45b7-a68c-2337d626738a"],
Cell[CellGroupData[{
Cell[212226, 5896, 748, 21, 81, "Input",ExpressionUUID->"6d7f1db9-546b-4f66-8eca-f0aa837a6042"],
Cell[212977, 5919, 784, 21, 55, "Output",ExpressionUUID->"cdf99bff-2681-4933-9c62-a1e19d7f6800"]
}, Open  ]],
Cell[CellGroupData[{
Cell[213798, 5945, 1619, 49, 160, "Input",ExpressionUUID->"b9c31de8-88cc-458e-9714-fa36524e49ff"],
Cell[215420, 5996, 840, 24, 69, "Output",ExpressionUUID->"f70600ce-45d9-4a2f-bd62-55adf716e005"],
Cell[216263, 6022, 842, 24, 69, "Output",ExpressionUUID->"d0ca4144-2089-4d4b-9d67-d46eea422687"]
}, Open  ]],
Cell[CellGroupData[{
Cell[217142, 6051, 1808, 48, 161, "Input",ExpressionUUID->"9fa4579c-afe0-4a4c-ad04-992f6612aa6b"],
Cell[218953, 6101, 726, 18, 61, "Output",ExpressionUUID->"ea149e85-5c0c-4cf2-8f29-41b2dc8d4b4c"],
Cell[219682, 6121, 726, 18, 61, "Output",ExpressionUUID->"ea689e1a-f90e-4296-9c04-09d371288b47"]
}, Open  ]],
Cell[CellGroupData[{
Cell[220445, 6144, 12965, 365, 650, "Input",ExpressionUUID->"6b3c11d5-1a9b-49c1-88c8-75c1d15ac958"],
Cell[233413, 6511, 2755, 84, 173, "Output",ExpressionUUID->"5fbb49a7-4ca8-4500-94cd-f10a5bcab5d6"],
Cell[236171, 6597, 1568, 46, 64, "Output",ExpressionUUID->"7c5a3dd3-7f14-48c9-9d0e-2ff72c8b1565"],
Cell[237742, 6645, 1596, 47, 64, "Output",ExpressionUUID->"f786cca1-2d73-412e-8254-ade6a1d9d2d1"],
Cell[239341, 6694, 1300, 37, 57, "Output",ExpressionUUID->"e83233bd-e4d2-4ce5-b5c4-d7112b69476c"],
Cell[240644, 6733, 1302, 37, 57, "Output",ExpressionUUID->"26c1f6d6-3ba9-42d0-b3e4-6bf54f27b2fd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241983, 6775, 4813, 139, 346, "Input",ExpressionUUID->"00eac9e0-ad47-4f5c-b42b-257193a72965"],
Cell[246799, 6916, 558, 15, 58, "Output",ExpressionUUID->"b2f75389-6e48-4a8e-9a35-46e5707d151a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[247394, 6936, 3203, 95, 382, "Input",ExpressionUUID->"9c7b4b83-f391-4a3e-a5fe-fa6cde19d452"],
Cell[250600, 7033, 320, 6, 37, "Output",ExpressionUUID->"01f9c5e6-1133-45b3-8098-073d08297158"],
Cell[250923, 7041, 319, 6, 37, "Output",ExpressionUUID->"22de54e8-0187-41b0-b8d8-de79e56d830d"],
Cell[251245, 7049, 316, 6, 37, "Output",ExpressionUUID->"485443e3-6999-46e1-8a7b-29f72652e7a8"],
Cell[251564, 7057, 311, 6, 37, "Output",ExpressionUUID->"8aef83d0-a9ad-4ca7-a3fa-587267af96dc"],
Cell[251878, 7065, 320, 6, 37, "Output",ExpressionUUID->"c6c8f512-646d-463e-933f-3c6502059b69"],
Cell[252201, 7073, 319, 6, 37, "Output",ExpressionUUID->"7f586946-aa34-49a6-a278-e532df0ae3c7"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

